;;; php-eldoc.el --- eldoc backend for php
;; Package-Version: 20140202.1941
;; Package-Revision: df05064146b8
;;; Author: sabof
;;; URL: https://github.com/sabof/php-eldoc

;;; Commentary:
;; You should find probe.php in the same directory as this file.
;;
;; The project is hosted at https://github.com/sabof/php-eldoc
;; The latest version, and all the relevant information can be found there.

;;; License:

;; This file is NOT part of GNU Emacs.
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program ; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:
(require 'cl)
(require 'thingatpt)
(defvar php-remote-functions nil)

(defvar php-eldoc-functions-hash
  (let ((hash (make-hash-table :size 2500 :test 'equal)))
    (mapc (lambda (func)
            (puthash (car func) (rest func) hash))
          '(("zend_version")
            ("func_num_args")
            ("func_get_arg" "$arg_num")
            ("func_get_args")
            ("strlen" "$str")
            ("strcmp" "$str1" "$str2")
            ("strncmp" "$str1" "$str2" "$len")
            ("strcasecmp" "$str1" "$str2")
            ("strncasecmp" "$str1" "$str2" "$len")
            ("each" "&$arr")
            ("error_reporting" "[$new_error_level]")
            ("define" "$constant_name" "$value" "$case_insensitive")
            ("defined" "$constant_name")
            ("get_class" "[$object]")
            ("get_called_class")
            ("get_parent_class" "[$object]")
            ("method_exists" "$object" "$method")
            ("property_exists" "$object_or_class" "$property_name")
            ("class_exists" "$classname" "[$autoload]")
            ("interface_exists" "$classname" "[$autoload]")
            ("function_exists" "$function_name")
            ("class_alias" "$user_class_name" "$alias_name" "[$autoload]")
            ("get_included_files")
            ("get_required_files")
            ("is_subclass_of" "$object" "$class_name")
            ("is_a" "$object" "$class_name")
            ("get_class_vars" "$class_name")
            ("get_object_vars" "$obj")
            ("get_class_methods" "$class")
            ("trigger_error" "$message" "[$error_type]")
            ("user_error" "$message" "[$error_type]")
            ("set_error_handler" "$error_handler" "[$error_types]")
            ("restore_error_handler")
            ("set_exception_handler" "$exception_handler")
            ("restore_exception_handler")
            ("get_declared_classes")
            ("get_declared_interfaces")
            ("get_defined_functions")
            ("get_defined_vars")
            ("create_function" "$args" "$code")
            ("get_resource_type" "$res")
            ("get_loaded_extensions" "[$zend_extensions]")
            ("extension_loaded" "$extension_name")
            ("get_extension_funcs" "$extension_name")
            ("get_defined_constants" "[$categorize]")
            ("debug_backtrace" "[$options]")
            ("debug_print_backtrace" "[$options]")
            ("gc_collect_cycles")
            ("gc_enabled")
            ("gc_enable")
            ("gc_disable")
            ("strtotime" "$time" "[$now]")
            ("date" "$format" "[$timestamp]")
            ("idate" "$format" "[$timestamp]")
            ("gmdate" "$format" "[$timestamp]")
            ("mktime" "[$hour]" "[$min]" "[$sec]" "[$mon]" "[$day]" "[$year]")
            ("gmmktime" "[$hour]" "[$min]" "[$sec]" "[$mon]" "[$day]" "[$year]")
            ("checkdate" "$month" "$day" "$year")
            ("strftime" "$format" "[$timestamp]")
            ("gmstrftime" "$format" "[$timestamp]")
            ("time")
            ("localtime" "[$timestamp]" "[$associative_array]")
            ("getdate" "[$timestamp]")
            ("date_create" "[$time]" "[$object]")
            ("date_create_from_format" "$format" "$time" "[$object]")
            ("date_parse" "$date")
            ("date_parse_from_format" "$format" "$date")
            ("date_get_last_errors")
            ("date_format" "$object" "$format")
            ("date_modify" "$object" "$modify")
            ("date_add" "$object" "$interval")
            ("date_sub" "$object" "$interval")
            ("date_timezone_get" "$object")
            ("date_timezone_set" "$object" "$timezone")
            ("date_offset_get" "$object")
            ("date_diff" "$object" "$object2" "[$absolute]")
            ("date_time_set" "$object" "$hour" "$minute" "[$second]")
            ("date_date_set" "$object" "$year" "$month" "$day")
            ("date_isodate_set" "$object" "$year" "$week" "[$day]")
            ("date_timestamp_set" "$object" "$unixtimestamp")
            ("date_timestamp_get" "$object")
            ("timezone_open" "$timezone")
            ("timezone_name_get" "$object")
            ("timezone_name_from_abbr" "$abbr" "[$gmtoffset]" "[$isdst]")
            ("timezone_offset_get" "$object" "$datetime")
            ("timezone_transitions_get" "$object" "[$timestamp_begin]" "[$timestamp_end]")
            ("timezone_location_get" "$object")
            ("timezone_identifiers_list" "[$what]" "[$country]")
            ("timezone_abbreviations_list")
            ("timezone_version_get")
            ("date_interval_create_from_date_string" "$time")
            ("date_interval_format" "$object" "$format")
            ("date_default_timezone_set" "$timezone_identifier")
            ("date_default_timezone_get")
            ("date_sunrise" "$time" "[$format]" "[$latitude]" "[$longitude]" "[$zenith]" "[$gmt_offset]")
            ("date_sunset" "$time" "[$format]" "[$latitude]" "[$longitude]" "[$zenith]" "[$gmt_offset]")
            ("date_sun_info" "$time" "$latitude" "$longitude")
            ("ereg" "$pattern" "$string" "[&$registers]")
            ("ereg_replace" "$pattern" "$replacement" "$string")
            ("eregi" "$pattern" "$string" "[&$registers]")
            ("eregi_replace" "$pattern" "$replacement" "$string")
            ("split" "$pattern" "$string" "[$limit]")
            ("spliti" "$pattern" "$string" "[$limit]")
            ("sql_regcase" "$string")
            ("libxml_set_streams_context" "$context")
            ("libxml_use_internal_errors" "[$use_errors]")
            ("libxml_get_last_error")
            ("libxml_clear_errors")
            ("libxml_get_errors")
            ("libxml_disable_entity_loader" "[$disable]")
            ("openssl_pkey_free" "$key")
            ("openssl_pkey_new" "[$configargs]")
            ("openssl_pkey_export" "$key" "&$out" "[$passphrase]" "[$config_args]")
            ("openssl_pkey_export_to_file" "$key" "$outfilename" "[$passphrase]" "[$config_args]")
            ("openssl_pkey_get_private" "$key" "[$passphrase]")
            ("openssl_pkey_get_public" "$cert")
            ("openssl_pkey_get_details" "$key")
            ("openssl_free_key" "$key")
            ("openssl_get_privatekey" "$key" "[$passphrase]")
            ("openssl_get_publickey" "$cert")
            ("openssl_x509_read" "$cert")
            ("openssl_x509_free" "$x509")
            ("openssl_x509_parse" "$x509" "$shortname")
            ("openssl_x509_checkpurpose" "$x509cert" "$purpose" "$cainfo" "[$untrustedfile]")
            ("openssl_x509_check_private_key" "$cert" "$key")
            ("openssl_x509_export" "$x509" "&$out" "[$notext]")
            ("openssl_x509_export_to_file" "$x509" "$outfilename" "[$notext]")
            ("openssl_pkcs12_export" "$x509" "&$out" "$priv_key" "$pass" "$args")
            ("openssl_pkcs12_export_to_file" "$x509" "$filename" "$priv_key" "$pass" "[$args]")
            ("openssl_pkcs12_read" "$PKCS12" "&$certs" "$pass")
            ("openssl_csr_new" "$dn" "&$privkey" "[$configargs]" "[$extraattribs]")
            ("openssl_csr_export" "$csr" "&$out" "[$notext]")
            ("openssl_csr_export_to_file" "$csr" "$outfilename" "[$notext]")
            ("openssl_csr_sign" "$csr" "$x509" "$priv_key" "$days" "[$config_args]" "[$serial]")
            ("openssl_csr_get_subject" "$csr")
            ("openssl_csr_get_public_key" "$csr")
            ("openssl_digest" "$data" "$method" "[$raw_output]")
            ("openssl_encrypt" "$data" "$method" "$password" "[$raw_output]" "[$iv]")
            ("openssl_decrypt" "$data" "$method" "$password" "[$raw_input]" "[$iv]")
            ("openssl_cipher_iv_length" "$method")
            ("openssl_sign" "$data" "&$signature" "$key" "[$method]")
            ("openssl_verify" "$data" "$signature" "$key" "[$method]")
            ("openssl_seal" "$data" "&$sealdata" "&$ekeys" "$pubkeys")
            ("openssl_open" "$data" "&$opendata" "$ekey" "$privkey")
            ("openssl_pkcs7_verify" "$filename" "$flags" "[$signerscerts]" "[$cainfo]" "[$extracerts]" "[$content]")
            ("openssl_pkcs7_decrypt" "$infilename" "$outfilename" "$recipcert" "[$recipkey]")
            ("openssl_pkcs7_sign" "$infile" "$outfile" "$signcert" "$signkey" "$headers" "[$flags]" "[$extracertsfilename]")
            ("openssl_pkcs7_encrypt" "$infile" "$outfile" "$recipcerts" "$headers" "[$flags]" "[$cipher]")
            ("openssl_private_encrypt" "$data" "&$crypted" "$key" "[$padding]")
            ("openssl_private_decrypt" "$data" "&$crypted" "$key" "[$padding]")
            ("openssl_public_encrypt" "$data" "&$crypted" "$key" "[$padding]")
            ("openssl_public_decrypt" "$data" "&$crypted" "$key" "[$padding]")
            ("openssl_get_md_methods" "[$aliases]")
            ("openssl_get_cipher_methods" "[$aliases]")
            ("openssl_dh_compute_key" "$pub_key" "$dh_key")
            ("openssl_random_pseudo_bytes" "$length" "[&$result_is_strong]")
            ("openssl_error_string")
            ("preg_match" "$pattern" "$subject" "[&$subpatterns]" "[$flags]" "[$offset]")
            ("preg_match_all" "$pattern" "$subject" "&$subpatterns" "[$flags]" "[$offset]")
            ("preg_replace" "$regex" "$replace" "$subject" "[$limit]" "[&$count]")
            ("preg_replace_callback" "$regex" "$callback" "$subject" "[$limit]" "[&$count]")
            ("preg_filter" "$regex" "$replace" "$subject" "[$limit]" "[&$count]")
            ("preg_split" "$pattern" "$subject" "[$limit]" "[$flags]")
            ("preg_quote" "$str" "[$delim_char]")
            ("preg_grep" "$regex" "$input" "[$flags]")
            ("preg_last_error")
            ("readgzfile" "$filename" "[$use_include_path]")
            ("gzrewind" "$fp")
            ("gzclose" "$fp")
            ("gzeof" "$fp")
            ("gzgetc" "$fp")
            ("gzgets" "$fp" "[$length]")
            ("gzgetss" "$fp" "[$length]" "[$allowable_tags]")
            ("gzread" "$fp" "$length")
            ("gzopen" "$filename" "$mode" "[$use_include_path]")
            ("gzpassthru" "$fp")
            ("gzseek" "$fp" "$offset" "[$whence]")
            ("gztell" "$fp")
            ("gzwrite" "$fp" "$str" "[$length]")
            ("gzputs" "$fp" "$str" "[$length]")
            ("gzfile" "$filename" "[$use_include_path]")
            ("gzcompress" "$data" "[$level]")
            ("gzuncompress" "$data" "[$length]")
            ("gzdeflate" "$data" "[$level]")
            ("gzinflate" "$data" "[$length]")
            ("gzencode" "$data" "[$level]" "[$encoding_mode]")
            ("ob_gzhandler" "$str" "$mode")
            ("zlib_get_coding_type")
            ("bcadd" "$left_operand" "$right_operand" "[$scale]")
            ("bcsub" "$left_operand" "$right_operand" "[$scale]")
            ("bcmul" "$left_operand" "$right_operand" "[$scale]")
            ("bcdiv" "$left_operand" "$right_operand" "[$scale]")
            ("bcmod" "$left_operand" "$right_operand")
            ("bcpow" "$x" "$y" "[$scale]")
            ("bcsqrt" "$operand" "[$scale]")
            ("bcscale" "$scale")
            ("bccomp" "$left_operand" "$right_operand" "[$scale]")
            ("bcpowmod" "$x" "$y" "$mod" "[$scale]")
            ("bzopen" "$file" "$mode")
            ("bzread" "$bz" "[$length]")
            ("bzwrite" "$fp" "$str" "[$length]")
            ("bzflush" "$fp")
            ("bzclose" "$fp")
            ("bzerrno" "$bz")
            ("bzerrstr" "$bz")
            ("bzerror" "$bz")
            ("bzcompress" "$source" "$blocksize" "[$workfactor]")
            ("bzdecompress" "$source" "[$small]")
            ("jdtogregorian" "$juliandaycount")
            ("gregoriantojd" "$month" "$day" "$year")
            ("jdtojulian" "$juliandaycount")
            ("juliantojd" "$month" "$day" "$year")
            ("jdtojewish" "$juliandaycount" "[$hebrew]" "[$fl]")
            ("jewishtojd" "$month" "$day" "$year")
            ("jdtofrench" "$juliandaycount")
            ("frenchtojd" "$month" "$day" "$year")
            ("jddayofweek" "$juliandaycount" "[$mode]")
            ("jdmonthname" "$juliandaycount" "$mode")
            ("easter_date" "[$year]")
            ("easter_days" "[$year]" "[$method]")
            ("unixtojd" "[$timestamp]")
            ("jdtounix" "$jday")
            ("cal_to_jd" "$calendar" "$month" "$day" "$year")
            ("cal_from_jd" "$jd" "$calendar")
            ("cal_days_in_month" "$calendar" "$month" "$year")
            ("cal_info" "[$calendar]")
            ("ctype_alnum" "$text")
            ("ctype_alpha" "$text")
            ("ctype_cntrl" "$text")
            ("ctype_digit" "$text")
            ("ctype_lower" "$text")
            ("ctype_graph" "$text")
            ("ctype_print" "$text")
            ("ctype_punct" "$text")
            ("ctype_space" "$text")
            ("ctype_upper" "$text")
            ("ctype_xdigit" "$text")
            ("curl_init" "[$url]")
            ("curl_copy_handle" "$ch")
            ("curl_version" "[$version]")
            ("curl_setopt" "$ch" "$option" "$value")
            ("curl_setopt_array" "$ch" "$options")
            ("curl_exec" "$ch")
            ("curl_getinfo" "$ch" "[$option]")
            ("curl_error" "$ch")
            ("curl_errno" "$ch")
            ("curl_close" "$ch")
            ("curl_multi_init")
            ("curl_multi_add_handle" "$mh" "$ch")
            ("curl_multi_remove_handle" "$mh" "$ch")
            ("curl_multi_select" "$mh" "[$timeout]")
            ("curl_multi_exec" "$mh" "[&$still_running]")
            ("curl_multi_getcontent" "$ch")
            ("curl_multi_info_read" "$mh" "[&$msgs_in_queue]")
            ("curl_multi_close" "$mh")
            ("dba_open" "$path" "$mode" "[$handlername]" "[$...]")
            ("dba_popen" "$path" "$mode" "[$handlername]" "[$...]")
            ("dba_close" "$handle")
            ("dba_delete" "$key" "$handle")
            ("dba_exists" "$key" "$handle")
            ("dba_fetch" "$key" "$skip" "[$handle]")
            ("dba_insert" "$key" "$value" "$handle")
            ("dba_replace" "$key" "$value" "$handle")
            ("dba_firstkey" "$handle")
            ("dba_nextkey" "$handle")
            ("dba_optimize" "$handle")
            ("dba_sync" "$handle")
            ("dba_handlers" "[$full_info]")
            ("dba_list")
            ("dba_key_split" "$key")
            ("dom_import_simplexml" "$node")
            ("exif_read_data" "$filename" "[$sections_needed]" "[$sub_arrays]" "[$read_thumbnail]")
            ("read_exif_data" "$filename" "[$sections_needed]" "[$sub_arrays]" "[$read_thumbnail]")
            ("exif_tagname" "$index")
            ("exif_thumbnail" "$filename" "[&$width]" "[&$height]" "[&$imagetype]")
            ("exif_imagetype" "$imagefile")
            ("finfo_open" "[$options]" "[$arg]")
            ("finfo_close" "$finfo")
            ("finfo_set_flags" "$finfo" "$options")
            ("finfo_file" "$finfo" "$filename" "[$options]" "[$context]")
            ("finfo_buffer" "$finfo" "$string" "[$options]" "[$context]")
            ("mime_content_type" "$string")
            ("filter_input" "$type" "$variable_name" "[$filter]" "[$options]")
            ("filter_var" "$variable" "[$filter]" "[$options]")
            ("filter_input_array" "$type" "[$definition]" "[$add_empty]")
            ("filter_var_array" "$data" "[$definition]" "[$add_empty]")
            ("filter_list")
            ("filter_has_var" "$type" "$variable_name")
            ("filter_id" "$filtername")
            ("ftp_connect" "$host" "[$port]" "[$timeout]")
            ("ftp_ssl_connect" "$host" "[$port]" "[$timeout]")
            ("ftp_login" "$ftp" "$username" "$password")
            ("ftp_pwd" "$ftp")
            ("ftp_cdup" "$ftp")
            ("ftp_chdir" "$ftp" "$directory")
            ("ftp_exec" "$ftp" "$command")
            ("ftp_raw" "$ftp" "$command")
            ("ftp_mkdir" "$ftp" "$directory")
            ("ftp_rmdir" "$ftp" "$directory")
            ("ftp_chmod" "$ftp" "$mode" "$filename")
            ("ftp_alloc" "$ftp" "$size" "[&$response]")
            ("ftp_nlist" "$ftp" "$directory")
            ("ftp_rawlist" "$ftp" "$directory" "[$recursive]")
            ("ftp_systype" "$ftp")
            ("ftp_pasv" "$ftp" "$pasv")
            ("ftp_get" "$ftp" "$local_file" "$remote_file" "$mode" "[$resume_pos]")
            ("ftp_fget" "$ftp" "$fp" "$remote_file" "$mode" "[$resumepos]")
            ("ftp_put" "$ftp" "$remote_file" "$local_file" "$mode" "[$startpos]")
            ("ftp_fput" "$ftp" "$remote_file" "$fp" "$mode" "[$startpos]")
            ("ftp_size" "$ftp" "$filename")
            ("ftp_mdtm" "$ftp" "$filename")
            ("ftp_rename" "$ftp" "$src" "$dest")
            ("ftp_delete" "$ftp" "$file")
            ("ftp_site" "$ftp" "$cmd")
            ("ftp_close" "$ftp")
            ("ftp_set_option" "$ftp" "$option" "$value")
            ("ftp_get_option" "$ftp" "$option")
            ("ftp_nb_fget" "$ftp" "$fp" "$remote_file" "$mode" "[$resumepos]")
            ("ftp_nb_get" "$ftp" "$local_file" "$remote_file" "$mode" "[$resume_pos]")
            ("ftp_nb_continue" "$ftp")
            ("ftp_nb_put" "$ftp" "$remote_file" "$local_file" "$mode" "[$startpos]")
            ("ftp_nb_fput" "$ftp" "$remote_file" "$fp" "$mode" "[$startpos]")
            ("ftp_quit" "$ftp")
            ("gd_info")
            ("imagearc" "$im" "$cx" "$cy" "$w" "$h" "$s" "$e" "$col")
            ("imageellipse" "$im" "$cx" "$cy" "$w" "$h" "$color")
            ("imagechar" "$im" "$font" "$x" "$y" "$c" "$col")
            ("imagecharup" "$im" "$font" "$x" "$y" "$c" "$col")
            ("imagecolorat" "$im" "$x" "$y")
            ("imagecolorallocate" "$im" "$red" "$green" "$blue")
            ("imagepalettecopy" "$dst" "$src")
            ("imagecreatefromstring" "$image")
            ("imagecolorclosest" "$im" "$red" "$green" "$blue")
            ("imagecolorclosesthwb" "$im" "$red" "$green" "$blue")
            ("imagecolordeallocate" "$im" "$index")
            ("imagecolorresolve" "$im" "$red" "$green" "$blue")
            ("imagecolorexact" "$im" "$red" "$green" "$blue")
            ("imagecolorset" "$im" "$color" "$red" "$green" "$blue")
            ("imagecolortransparent" "$im" "[$col]")
            ("imagecolorstotal" "$im")
            ("imagecolorsforindex" "$im" "$index")
            ("imagecopy" "$dst_im" "$src_im" "$dst_x" "$dst_y" "$src_x" "$src_y" "$src_w" "$src_h")
            ("imagecopymerge" "$src_im" "$dst_im" "$dst_x" "$dst_y" "$src_x" "$src_y" "$src_w" "$src_h" "$pct")
            ("imagecopymergegray" "$src_im" "$dst_im" "$dst_x" "$dst_y" "$src_x" "$src_y" "$src_w" "$src_h" "$pct")
            ("imagecopyresized" "$dst_im" "$src_im" "$dst_x" "$dst_y" "$src_x" "$src_y" "$dst_w" "$dst_h" "$src_w" "$src_h")
            ("imagecreate" "$x_size" "$y_size")
            ("imagecreatetruecolor" "$x_size" "$y_size")
            ("imageistruecolor" "$im")
            ("imagetruecolortopalette" "$im" "$ditherFlag" "$colorsWanted")
            ("imagesetthickness" "$im" "$thickness")
            ("imagefilledarc" "$im" "$cx" "$cy" "$w" "$h" "$s" "$e" "$col" "$style")
            ("imagefilledellipse" "$im" "$cx" "$cy" "$w" "$h" "$color")
            ("imagealphablending" "$im" "$blend")
            ("imagesavealpha" "$im" "$save")
            ("imagecolorallocatealpha" "$im" "$red" "$green" "$blue" "$alpha")
            ("imagecolorresolvealpha" "$im" "$red" "$green" "$blue" "$alpha")
            ("imagecolorclosestalpha" "$im" "$red" "$green" "$blue" "$alpha")
            ("imagecolorexactalpha" "$im" "$red" "$green" "$blue" "$alpha")
            ("imagecopyresampled" "$dst_im" "$src_im" "$dst_x" "$dst_y" "$src_x" "$src_y" "$dst_w" "$dst_h" "$src_w" "$src_h")
            ("imagerotate" "$im" "$angle" "$bgdcolor" "[$ignoretransparent]")
            ("imageantialias" "$im" "$on")
            ("imagesettile" "$im" "$tile")
            ("imagesetbrush" "$im" "$brush")
            ("imagesetstyle" "$im" "$styles")
            ("imagecreatefrompng" "$filename")
            ("imagecreatefromgif" "$filename")
            ("imagecreatefromjpeg" "$filename")
            ("imagecreatefromwbmp" "$filename")
            ("imagecreatefromxbm" "$filename")
            ("imagecreatefromgd" "$filename")
            ("imagecreatefromgd2" "$filename")
            ("imagecreatefromgd2part" "$filename" "$srcX" "$srcY" "$width" "$height")
            ("imagepng" "$im" "[$filename]")
            ("imagegif" "$im" "[$filename]")
            ("imagejpeg" "$im" "[$filename]" "[$quality]")
            ("imagewbmp" "$im" "[$filename]" "[$foreground]")
            ("imagegd" "$im" "[$filename]")
            ("imagegd2" "$im" "[$filename]" "[$chunk_size]" "[$type]")
            ("imagedestroy" "$im")
            ("imagegammacorrect" "$im" "$inputgamma" "$outputgamma")
            ("imagefill" "$im" "$x" "$y" "$col")
            ("imagefilledpolygon" "$im" "$points" "$num_pos" "$col")
            ("imagefilledrectangle" "$im" "$x1" "$y1" "$x2" "$y2" "$col")
            ("imagefilltoborder" "$im" "$x" "$y" "$border" "$col")
            ("imagefontwidth" "$font")
            ("imagefontheight" "$font")
            ("imageinterlace" "$im" "[$interlace]")
            ("imageline" "$im" "$x1" "$y1" "$x2" "$y2" "$col")
            ("imageloadfont" "$filename")
            ("imagepolygon" "$im" "$points" "$num_pos" "$col")
            ("imagerectangle" "$im" "$x1" "$y1" "$x2" "$y2" "$col")
            ("imagesetpixel" "$im" "$x" "$y" "$col")
            ("imagestring" "$im" "$font" "$x" "$y" "$str" "$col")
            ("imagestringup" "$im" "$font" "$x" "$y" "$str" "$col")
            ("imagesx" "$im")
            ("imagesy" "$im")
            ("imagedashedline" "$im" "$x1" "$y1" "$x2" "$y2" "$col")
            ("imagettfbbox" "$size" "$angle" "$font_file" "$text")
            ("imagettftext" "$im" "$size" "$angle" "$x" "$y" "$col" "$font_file" "$text")
            ("imageftbbox" "$size" "$angle" "$font_file" "$text" "[$extrainfo]")
            ("imagefttext" "$im" "$size" "$angle" "$x" "$y" "$col" "$font_file" "$text" "[$extrainfo]")
            ("imagetypes")
            ("jpeg2wbmp" "$f_org" "$f_dest" "$d_height" "$d_width" "$d_threshold")
            ("png2wbmp" "$f_org" "$f_dest" "$d_height" "$d_width" "$d_threshold")
            ("image2wbmp" "$im" "[$filename]" "[$threshold]")
            ("imagelayereffect" "$im" "$effect")
            ("imagexbm" "$im" "$filename" "[$foreground]")
            ("imagecolormatch" "$im1" "$im2")
            ("imagefilter" "$im" "$filtertype" "[$arg1]" "[$arg2]" "[$arg3]" "[$arg4]")
            ("imageconvolution" "$im" "$matrix3x3" "$div" "$offset")
            ("textdomain" "$domain")
            ("gettext" "$msgid")
            ("_" "$msgid")
            ("dgettext" "$domain_name" "$msgid")
            ("dcgettext" "$domain_name" "$msgid" "$category")
            ("bindtextdomain" "$domain_name" "$dir")
            ("ngettext" "$msgid1" "$msgid2" "$count")
            ("dngettext" "$domain" "$msgid1" "$msgid2" "$count")
            ("dcngettext" "$domain" "$msgid1" "$msgid2" "$count" "$category")
            ("bind_textdomain_codeset" "$domain" "$codeset")
            ("hash" "$algo" "$data" "[$raw_output]")
            ("hash_file" "$algo" "$filename" "[$raw_output]")
            ("hash_hmac" "$algo" "$data" "$key" "[$raw_output]")
            ("hash_hmac_file" "$algo" "$filename" "$key" "[$raw_output]")
            ("hash_init" "$algo" "[$options]" "[$key]")
            ("hash_update" "$context" "$data")
            ("hash_update_stream" "$context" "$handle" "[$length]")
            ("hash_update_file" "$context" "$filename" "[$context]")
            ("hash_final" "$context" "[$raw_output]")
            ("hash_copy" "$context")
            ("hash_algos")
            ("mhash_keygen_s2k" "$hash" "$input_password" "$salt" "$bytes")
            ("mhash_get_block_size" "$hash")
            ("mhash_get_hash_name" "$hash")
            ("mhash_count")
            ("mhash" "$hash" "$data" "[$key]")
            ("iconv" "$in_charset" "$out_charset" "$str")
            ("ob_iconv_handler" "$contents" "$status")
            ("iconv_get_encoding" "[$type]")
            ("iconv_set_encoding" "$type" "$charset")
            ("iconv_strlen" "$str" "[$charset]")
            ("iconv_substr" "$str" "$offset" "[$length]" "[$charset]")
            ("iconv_strpos" "$haystack" "$needle" "[$offset]" "[$charset]")
            ("iconv_strrpos" "$haystack" "$needle" "[$charset]")
            ("iconv_mime_encode" "$field_name" "$field_value" "[$preference]")
            ("iconv_mime_decode" "$encoded_string" "[$mode]" "[$charset]")
            ("iconv_mime_decode_headers" "$headers" "[$mode]" "[$charset]")
            ("imap_open" "$mailbox" "$user" "$password" "[$options]" "[$n_retries]" "[$params]")
            ("imap_reopen" "$stream_id" "$mailbox" "[$options]" "[$n_retries]")
            ("imap_close" "$stream_id" "[$options]")
            ("imap_num_msg" "$stream_id")
            ("imap_num_recent" "$stream_id")
            ("imap_headers" "$stream_id")
            ("imap_headerinfo" "$stream_id" "$msg_no" "[$from_length]" "[$subject_length]" "[$default_host]")
            ("imap_rfc822_parse_headers" "$headers" "[$default_host]")
            ("imap_rfc822_write_address" "$mailbox" "$host" "$personal")
            ("imap_rfc822_parse_adrlist" "$address_string" "$default_host")
            ("imap_body" "$stream_id" "$msg_no" "[$options]")
            ("imap_bodystruct" "$stream_id" "$msg_no" "$section")
            ("imap_fetchbody" "$stream_id" "$msg_no" "$section" "[$options]")
            ("imap_fetchmime" "$stream_id" "$msg_no" "$section" "[$options]")
            ("imap_savebody" "$stream_id" "$file" "$msg_no" "[$section]" "[$options]")
            ("imap_fetchheader" "$stream_id" "$msg_no" "[$options]")
            ("imap_fetchstructure" "$stream_id" "$msg_no" "[$options]")
            ("imap_gc" "$stream_id" "[$flags]")
            ("imap_expunge" "$stream_id")
            ("imap_delete" "$stream_id" "$msg_no" "[$options]")
            ("imap_undelete" "$stream_id" "$msg_no" "[$flags]")
            ("imap_check" "$stream_id")
            ("imap_listscan" "$stream_id" "$ref" "$pattern" "$content")
            ("imap_mail_copy" "$stream_id" "$msglist" "$mailbox" "[$options]")
            ("imap_mail_move" "$stream_id" "$sequence" "$mailbox" "[$options]")
            ("imap_mail_compose" "$envelope" "$body")
            ("imap_createmailbox" "$stream_id" "$mailbox")
            ("imap_renamemailbox" "$stream_id" "$old_name" "$new_name")
            ("imap_deletemailbox" "$stream_id" "$mailbox")
            ("imap_subscribe" "$stream_id" "$mailbox")
            ("imap_unsubscribe" "$stream_id" "$mailbox")
            ("imap_append" "$stream_id" "$folder" "$message" "[$options]" "[$date]")
            ("imap_ping" "$stream_id")
            ("imap_base64" "$text")
            ("imap_qprint" "$text")
            ("imap_8bit" "$text")
            ("imap_binary" "$text")
            ("imap_utf8" "$mime_encoded_text")
            ("imap_status" "$stream_id" "$mailbox" "$options")
            ("imap_mailboxmsginfo" "$stream_id")
            ("imap_setflag_full" "$stream_id" "$sequence" "$flag" "[$options]")
            ("imap_clearflag_full" "$stream_id" "$sequence" "$flag" "[$options]")
            ("imap_sort" "$stream_id" "$criteria" "$reverse" "[$options]" "[$search_criteria]" "[$charset]")
            ("imap_uid" "$stream_id" "$msg_no")
            ("imap_msgno" "$stream_id" "$unique_msg_id")
            ("imap_list" "$stream_id" "$ref" "$pattern")
            ("imap_lsub" "$stream_id" "$ref" "$pattern")
            ("imap_fetch_overview" "$stream_id" "$sequence" "[$options]")
            ("imap_alerts")
            ("imap_errors")
            ("imap_last_error")
            ("imap_search" "$stream_id" "$criteria" "[$options]" "[$charset]")
            ("imap_utf7_decode" "$buf")
            ("imap_utf7_encode" "$buf")
            ("imap_utf8_to_mutf7" "$in")
            ("imap_mutf7_to_utf8" "$in")
            ("imap_mime_header_decode" "$str")
            ("imap_thread" "$stream_id" "[$options]")
            ("imap_timeout" "$timeout_type" "[$timeout]")
            ("imap_get_quota" "$stream_id" "$qroot")
            ("imap_get_quotaroot" "$stream_id" "$mbox")
            ("imap_set_quota" "$stream_id" "$qroot" "$mailbox_size")
            ("imap_setacl" "$stream_id" "$mailbox" "$id" "$rights")
            ("imap_getacl" "$stream_id" "$mailbox")
            ("imap_mail" "$to" "$subject" "$message" "[$additional_headers]" "[$cc]" "[$bcc]" "[$rpath]")
            ("imap_header" "$stream_id" "$msg_no" "[$from_length]" "[$subject_length]" "[$default_host]")
            ("imap_listmailbox" "$stream_id" "$ref" "$pattern")
            ("imap_getmailboxes" "$stream_id" "$ref" "$pattern")
            ("imap_scanmailbox" "$stream_id" "$ref" "$pattern" "$content")
            ("imap_listsubscribed" "$stream_id" "$ref" "$pattern")
            ("imap_getsubscribed" "$stream_id" "$ref" "$pattern")
            ("imap_fetchtext" "$stream_id" "$msg_no" "[$options]")
            ("imap_scan" "$stream_id" "$ref" "$pattern" "$content")
            ("imap_create" "$stream_id" "$mailbox")
            ("imap_rename" "$stream_id" "$old_name" "$new_name")
            ("collator_create" "$arg1")
            ("collator_compare" "$object" "$arg1" "$arg2")
            ("collator_get_attribute" "$object" "$arg1")
            ("collator_set_attribute" "$object" "$arg1" "$arg2")
            ("collator_get_strength" "$object")
            ("collator_set_strength" "$object" "$arg1")
            ("collator_sort" "$object" "&$arr" "[$sort_flags]")
            ("collator_sort_with_sort_keys" "$object" "&$arr" "[$sort_flags]")
            ("collator_asort" "$object" "&$arr" "[$sort_flags]")
            ("collator_get_locale" "$object" "$arg1")
            ("collator_get_error_code" "$object")
            ("collator_get_error_message" "$object")
            ("collator_get_sort_key" "$object" "$arg1" "$arg2")
            ("numfmt_create" "$locale" "$style" "[$pattern]")
            ("numfmt_format" "$nf" "$num" "[$type]")
            ("numfmt_parse" "$formatter" "$string" "[$type]" "[&$position]")
            ("numfmt_format_currency" "$nf" "$num" "$currency")
            ("numfmt_parse_currency" "$formatter" "$string" "&$currency" "[&$position]")
            ("numfmt_set_attribute" "$nf" "$attr" "$value")
            ("numfmt_get_attribute" "$nf" "$attr")
            ("numfmt_set_text_attribute" "$nf" "$attr" "$value")
            ("numfmt_get_text_attribute" "$nf" "$attr")
            ("numfmt_set_symbol" "$nf" "$attr" "$symbol")
            ("numfmt_get_symbol" "$nf" "$attr")
            ("numfmt_set_pattern" "$nf" "$pattern")
            ("numfmt_get_pattern" "$nf")
            ("numfmt_get_locale" "$nf" "[$type]")
            ("numfmt_get_error_code" "$nf")
            ("numfmt_get_error_message" "$nf")
            ("normalizer_normalize" "$input" "[$form]")
            ("normalizer_is_normalized" "$input" "[$form]")
            ("locale_get_default")
            ("locale_set_default" "$arg1")
            ("locale_get_primary_language" "$arg1")
            ("locale_get_script" "$arg1")
            ("locale_get_region" "$arg1")
            ("locale_get_keywords" "$arg1")
            ("locale_get_display_script" "$arg1" "$arg2")
            ("locale_get_display_region" "$arg1" "$arg2")
            ("locale_get_display_name" "$arg1" "$arg2")
            ("locale_get_display_language" "$arg1" "$arg2")
            ("locale_get_display_variant" "$arg1" "$arg2")
            ("locale_compose" "$arg1")
            ("locale_parse" "$arg1")
            ("locale_get_all_variants" "$arg1")
            ("locale_filter_matches" "$arg1" "$arg2" "$arg3")
            ("locale_canonicalize" "$arg1")
            ("locale_lookup" "$arg1" "$arg2" "$arg3" "$arg4")
            ("locale_accept_from_http" "$arg1")
            ("msgfmt_create" "$locale" "$pattern")
            ("msgfmt_format" "$nf" "$args")
            ("msgfmt_format_message" "$locale" "$pattern" "$args")
            ("msgfmt_parse" "$nf" "$source")
            ("msgfmt_parse_message" "$locale" "$pattern" "$source")
            ("msgfmt_set_pattern" "$mf" "$pattern")
            ("msgfmt_get_pattern" "$mf")
            ("msgfmt_get_locale" "$mf")
            ("msgfmt_get_error_code" "$nf")
            ("msgfmt_get_error_message" "$coll")
            ("datefmt_create" "$locale" "$date_type" "$time_type" "[$timezone_str]" "[$calendar]" "[$pattern]")
            ("datefmt_get_datetype" "$mf")
            ("datefmt_get_timetype" "$mf")
            ("datefmt_get_calendar" "$mf")
            ("datefmt_set_calendar" "$mf" "$calendar")
            ("datefmt_get_locale" "$mf")
            ("datefmt_get_timezone_id" "$mf")
            ("datefmt_set_timezone_id" "$mf")
            ("datefmt_get_pattern" "$mf")
            ("datefmt_set_pattern" "$mf" "$pattern")
            ("datefmt_is_lenient" "$mf")
            ("datefmt_set_lenient" "$mf")
            ("datefmt_format" "[$args]" "[$array]")
            ("datefmt_parse" "$formatter" "$string" "[&$position]")
            ("datefmt_localtime" "$formatter" "$string" "[&$position]")
            ("datefmt_get_error_code" "$nf")
            ("datefmt_get_error_message" "$coll")
            ("grapheme_strlen" "$string")
            ("grapheme_strpos" "$haystack" "$needle" "[$offset]")
            ("grapheme_stripos" "$haystack" "$needle" "[$offset]")
            ("grapheme_strrpos" "$haystack" "$needle" "[$offset]")
            ("grapheme_strripos" "$haystack" "$needle" "[$offset]")
            ("grapheme_substr" "$string" "$start" "[$length]")
            ("grapheme_strstr" "$haystack" "$needle" "[$before_needle]")
            ("grapheme_stristr" "$haystack" "$needle" "[$before_needle]")
            ("grapheme_extract" "$arg1" "$arg2" "[$arg3]" "[$arg4]" "[&$arg5]")
            ("idn_to_ascii" "$domain" "[$option]" "[$status]")
            ("idn_to_utf8" "$domain" "[$option]" "[$status]")
            ("resourcebundle_create" "$locale" "$bundlename" "[$fallback]")
            ("resourcebundle_get" "$bundle" "$index" "[$fallback]")
            ("resourcebundle_count" "$bundle")
            ("resourcebundle_locales" "$bundlename")
            ("resourcebundle_get_error_code" "$bundle")
            ("resourcebundle_get_error_message" "$bundle")
            ("intl_get_error_code")
            ("intl_get_error_message")
            ("intl_is_failure" "$arg1")
            ("intl_error_name" "$arg1")
            ("json_encode" "$value" "[$options]")
            ("json_decode" "$json" "[$assoc]" "[$depth]")
            ("json_last_error")
            ("ldap_connect" "[$hostname]" "[$port]")
            ("ldap_close" "$link_identifier")
            ("ldap_bind" "$link_identifier" "[$bind_rdn]" "[$bind_password]")
            ("ldap_unbind" "$link_identifier")
            ("ldap_read" "$link_identifier" "$base_dn" "$filter" "[$attributes]" "[$attrsonly]" "[$sizelimit]" "[$timelimit]" "[$deref]")
            ("ldap_list" "$link_identifier" "$base_dn" "$filter" "[$attributes]" "[$attrsonly]" "[$sizelimit]" "[$timelimit]" "[$deref]")
            ("ldap_search" "$link_identifier" "$base_dn" "$filter" "[$attributes]" "[$attrsonly]" "[$sizelimit]" "[$timelimit]" "[$deref]")
            ("ldap_free_result" "$link_identifier")
            ("ldap_count_entries" "$link_identifier" "$result_identifier")
            ("ldap_first_entry" "$link_identifier" "$result_identifier")
            ("ldap_next_entry" "$link_identifier" "$result_identifier")
            ("ldap_get_entries" "$link_identifier" "$result_identifier")
            ("ldap_first_attribute" "$link_identifier" "$result_entry_identifier")
            ("ldap_next_attribute" "$link_identifier" "$result_entry_identifier")
            ("ldap_get_attributes" "$link_identifier" "$result_entry_identifier")
            ("ldap_get_values" "$link_identifier" "$result_entry_identifier" "$attribute")
            ("ldap_get_values_len" "$link_identifier" "$result_entry_identifier" "$attribute")
            ("ldap_get_dn" "$link_identifier" "$result_entry_identifier")
            ("ldap_explode_dn" "$dn" "$with_attrib")
            ("ldap_dn2ufn" "$dn")
            ("ldap_add" "$link_identifier" "$dn" "$entry")
            ("ldap_delete" "$link_identifier" "$dn")
            ("ldap_modify" "$link_identifier" "$dn" "$entry")
            ("ldap_mod_add" "$link_identifier" "$dn" "$entry")
            ("ldap_mod_replace" "$link_identifier" "$dn" "$entry")
            ("ldap_mod_del" "$link_identifier" "$dn" "$entry")
            ("ldap_errno" "$link_identifier")
            ("ldap_err2str" "$errno")
            ("ldap_error" "$link_identifier")
            ("ldap_compare" "$link_identifier" "$dn" "$attribute" "$value")
            ("ldap_sort" "$link" "$result" "$sortfilter")
            ("ldap_rename" "$link_identifier" "$dn" "$newrdn" "$newparent" "$deleteoldrdn")
            ("ldap_get_option" "$link_identifier" "$option" "&$retval")
            ("ldap_set_option" "$link_identifier" "$option" "$newval")
            ("ldap_first_reference" "$link" "$result")
            ("ldap_next_reference" "$link" "$entry")
            ("ldap_parse_reference" "$link" "$entry" "&$referrals")
            ("ldap_parse_result" "$link" "$result" "&$errcode" "[&$matcheddn]" "[&$errmsg]" "[&$referrals]")
            ("ldap_start_tls" "$link_identifier")
            ("ldap_set_rebind_proc" "$link" "$callback")
            ("mb_convert_case" "$sourcestring" "$mode" "[$encoding]")
            ("mb_strtoupper" "$sourcestring" "[$encoding]")
            ("mb_strtolower" "$sourcestring" "[$encoding]")
            ("mb_language" "[$language]")
            ("mb_internal_encoding" "[$encoding]")
            ("mb_http_input" "[$type]")
            ("mb_http_output" "[$encoding]")
            ("mb_detect_order" "[$encoding]")
            ("mb_substitute_character" "[$substchar]")
            ("mb_parse_str" "$encoded_string" "[&$result]")
            ("mb_output_handler" "$contents" "$status")
            ("mb_preferred_mime_name" "$encoding")
            ("mb_strlen" "$str" "[$encoding]")
            ("mb_strpos" "$haystack" "$needle" "[$offset]" "[$encoding]")
            ("mb_strrpos" "$haystack" "$needle" "[$offset]" "[$encoding]")
            ("mb_stripos" "$haystack" "$needle" "[$offset]" "[$encoding]")
            ("mb_strripos" "$haystack" "$needle" "[$offset]" "[$encoding]")
            ("mb_strstr" "$haystack" "$needle" "[$part]" "[$encoding]")
            ("mb_strrchr" "$haystack" "$needle" "[$part]" "[$encoding]")
            ("mb_stristr" "$haystack" "$needle" "[$part]" "[$encoding]")
            ("mb_strrichr" "$haystack" "$needle" "[$part]" "[$encoding]")
            ("mb_substr_count" "$haystack" "$needle" "[$encoding]")
            ("mb_substr" "$str" "$start" "[$length]" "[$encoding]")
            ("mb_strcut" "$str" "$start" "[$length]" "[$encoding]")
            ("mb_strwidth" "$str" "[$encoding]")
            ("mb_strimwidth" "$str" "$start" "$width" "[$trimmarker]" "[$encoding]")
            ("mb_convert_encoding" "$str" "$to" "[$from]")
            ("mb_detect_encoding" "$str" "[$encoding_list]" "[$strict]")
            ("mb_list_encodings")
            ("mb_encoding_aliases" "$encoding")
            ("mb_convert_kana" "$str" "[$option]" "[$encoding]")
            ("mb_encode_mimeheader" "$str" "[$charset]" "[$transfer]" "[$linefeed]" "[$indent]")
            ("mb_decode_mimeheader" "$string")
            ("mb_convert_variables" "$to" "$from" "&$...")
            ("mb_encode_numericentity" "$string" "$convmap" "[$encoding]")
            ("mb_decode_numericentity" "$string" "$convmap" "[$encoding]")
            ("mb_send_mail" "$to" "$subject" "$message" "[$additional_headers]" "[$additional_parameters]")
            ("mb_get_info" "[$type]")
            ("mb_check_encoding" "[$var]" "[$encoding]")
            ("mb_regex_encoding" "[$encoding]")
            ("mb_regex_set_options" "[$options]")
            ("mb_ereg" "$pattern" "$string" "[&$registers]")
            ("mb_eregi" "$pattern" "$string" "[&$registers]")
            ("mb_ereg_replace" "$pattern" "$replacement" "$string" "[$option]")
            ("mb_eregi_replace" "$pattern" "$replacement" "$string")
            ("mb_split" "$pattern" "$string" "[$limit]")
            ("mb_ereg_match" "$pattern" "$string" "[$option]")
            ("mb_ereg_search" "[$pattern]" "[$option]")
            ("mb_ereg_search_pos" "[$pattern]" "[$option]")
            ("mb_ereg_search_regs" "[$pattern]" "[$option]")
            ("mb_ereg_search_init" "$string" "[$pattern]" "[$option]")
            ("mb_ereg_search_getregs")
            ("mb_ereg_search_getpos")
            ("mb_ereg_search_setpos" "$position")
            ("mbregex_encoding" "[$encoding]")
            ("mbereg" "$pattern" "$string" "[&$registers]")
            ("mberegi" "$pattern" "$string" "[&$registers]")
            ("mbereg_replace" "$pattern" "$replacement" "$string" "[$option]")
            ("mberegi_replace" "$pattern" "$replacement" "$string")
            ("mbsplit" "$pattern" "$string" "[$limit]")
            ("mbereg_match" "$pattern" "$string" "[$option]")
            ("mbereg_search" "[$pattern]" "[$option]")
            ("mbereg_search_pos" "[$pattern]" "[$option]")
            ("mbereg_search_regs" "[$pattern]" "[$option]")
            ("mbereg_search_init" "$string" "[$pattern]" "[$option]")
            ("mbereg_search_getregs")
            ("mbereg_search_getpos")
            ("mbereg_search_setpos" "$position")
            ("mcrypt_ecb" "$cipher" "$key" "$data" "$mode" "$iv")
            ("mcrypt_cbc" "$cipher" "$key" "$data" "$mode" "$iv")
            ("mcrypt_cfb" "$cipher" "$key" "$data" "$mode" "$iv")
            ("mcrypt_ofb" "$cipher" "$key" "$data" "$mode" "$iv")
            ("mcrypt_get_key_size" "$cipher" "$module")
            ("mcrypt_get_block_size" "$cipher" "$module")
            ("mcrypt_get_cipher_name" "$cipher")
            ("mcrypt_create_iv" "$size" "$source")
            ("mcrypt_list_algorithms" "[$lib_dir]")
            ("mcrypt_list_modes" "[$lib_dir]")
            ("mcrypt_get_iv_size" "$cipher" "$module")
            ("mcrypt_encrypt" "$cipher" "$key" "$data" "$mode" "$iv")
            ("mcrypt_decrypt" "$cipher" "$key" "$data" "$mode" "$iv")
            ("mcrypt_module_open" "$cipher" "$cipher_directory" "$mode" "$mode_directory")
            ("mcrypt_generic_init" "$td" "$key" "$iv")
            ("mcrypt_generic" "$td" "$data")
            ("mdecrypt_generic" "$td" "$data")
            ("mcrypt_generic_end" "$td")
            ("mcrypt_generic_deinit" "$td")
            ("mcrypt_enc_self_test" "$td")
            ("mcrypt_enc_is_block_algorithm_mode" "$td")
            ("mcrypt_enc_is_block_algorithm" "$td")
            ("mcrypt_enc_is_block_mode" "$td")
            ("mcrypt_enc_get_block_size" "$td")
            ("mcrypt_enc_get_key_size" "$td")
            ("mcrypt_enc_get_supported_key_sizes" "$td")
            ("mcrypt_enc_get_iv_size" "$td")
            ("mcrypt_enc_get_algorithms_name" "$td")
            ("mcrypt_enc_get_modes_name" "$td")
            ("mcrypt_module_self_test" "$algorithm" "[$lib_dir]")
            ("mcrypt_module_is_block_algorithm_mode" "$mode" "[$lib_dir]")
            ("mcrypt_module_is_block_algorithm" "$algorithm" "[$lib_dir]")
            ("mcrypt_module_is_block_mode" "$mode" "[$lib_dir]")
            ("mcrypt_module_get_algo_block_size" "$algorithm" "[$lib_dir]")
            ("mcrypt_module_get_algo_key_size" "$algorithm" "[$lib_dir]")
            ("mcrypt_module_get_supported_key_sizes" "$algorithm" "[$lib_dir]")
            ("mcrypt_module_close" "$td")
            ("mssql_connect" "[$servername]" "[$username]" "[$password]" "[$newlink]")
            ("mssql_pconnect" "[$servername]" "[$username]" "[$password]" "[$newlink]")
            ("mssql_close" "[$link_identifier]")
            ("mssql_select_db" "$database_name" "[$link_identifier]")
            ("mssql_query" "$query" "[$link_identifier]" "[$batch_size]")
            ("mssql_fetch_batch" "$result")
            ("mssql_rows_affected" "$link_identifier")
            ("mssql_free_result" "$result")
            ("mssql_get_last_message")
            ("mssql_num_rows" "$result")
            ("mssql_num_fields" "$result")
            ("mssql_fetch_field" "$result" "[$field_offset]")
            ("mssql_fetch_row" "$result")
            ("mssql_fetch_array" "$result" "[$result_type]")
            ("mssql_fetch_assoc" "$result_id")
            ("mssql_fetch_object" "$result")
            ("mssql_field_length" "$result" "[$offset]")
            ("mssql_field_name" "$result" "[$offset]")
            ("mssql_field_type" "$result" "[$offset]")
            ("mssql_data_seek" "$result_identifier" "$row_number")
            ("mssql_field_seek" "$result" "[$field_offset]")
            ("mssql_result" "$result" "$row" "$field")
            ("mssql_next_result" "$result_id")
            ("mssql_min_error_severity" "$severity")
            ("mssql_min_message_severity" "$severity")
            ("mssql_init" "$sp_name" "[$link_identifier]")
            ("mssql_bind" "$stmt" "$param_name" "&$var" "$type" "[$is_output]" "[$is_null]" "[$maxlen]")
            ("mssql_execute" "$stmt" "[$skip_results]")
            ("mssql_free_statement" "$stmt")
            ("mssql_guid_string" "$binary" "[$short_format]")
            ("mysql_connect" "[$hostname]" "[$username]" "[$password]" "[$new]" "[$flags]")
            ("mysql_pconnect" "[$hostname]" "[$username]" "[$password]" "[$flags]")
            ("mysql_close" "[$link_identifier]")
            ("mysql_select_db" "$database_name" "[$link_identifier]")
            ("mysql_query" "$query" "[$link_identifier]")
            ("mysql_unbuffered_query" "$query" "[$link_identifier]")
            ("mysql_db_query" "$database_name" "$query" "[$link_identifier]")
            ("mysql_list_dbs" "[$link_identifier]")
            ("mysql_list_tables" "$database_name" "[$link_identifier]")
            ("mysql_list_fields" "$database_name" "$table_name" "[$link_identifier]")
            ("mysql_list_processes" "[$link_identifier]")
            ("mysql_error" "[$link_identifier]")
            ("mysql_errno" "[$link_identifier]")
            ("mysql_affected_rows" "[$link_identifier]")
            ("mysql_insert_id" "[$link_identifier]")
            ("mysql_result" "$result" "$row" "[$field]")
            ("mysql_num_rows" "$result")
            ("mysql_num_fields" "$result")
            ("mysql_fetch_row" "$result")
            ("mysql_fetch_array" "$result" "[$result_type]")
            ("mysql_fetch_assoc" "$result")
            ("mysql_fetch_object" "$result" "[$class_name]" "[$ctor_params]")
            ("mysql_data_seek" "$result" "$row_number")
            ("mysql_fetch_lengths" "$result")
            ("mysql_fetch_field" "$result" "[$field_offset]")
            ("mysql_field_seek" "$result" "$field_offset")
            ("mysql_free_result" "$result")
            ("mysql_field_name" "$result" "$field_index")
            ("mysql_field_table" "$result" "$field_offset")
            ("mysql_field_len" "$result" "$field_offset")
            ("mysql_field_type" "$result" "$field_offset")
            ("mysql_field_flags" "$result" "$field_offset")
            ("mysql_escape_string" "$string")
            ("mysql_real_escape_string" "$string" "[$link_identifier]")
            ("mysql_stat" "[$link_identifier]")
            ("mysql_thread_id" "[$link_identifier]")
            ("mysql_client_encoding" "[$link_identifier]")
            ("mysql_ping" "[$link_identifier]")
            ("mysql_get_client_info")
            ("mysql_get_host_info" "[$link_identifier]")
            ("mysql_get_proto_info" "[$link_identifier]")
            ("mysql_get_server_info" "[$link_identifier]")
            ("mysql_info" "[$link_identifier]")
            ("mysql_set_charset" "$charset_name" "[$link_identifier]")
            ("mysql" "$database_name" "$query" "[$link_identifier]")
            ("mysql_fieldname" "$result" "$field_index")
            ("mysql_fieldtable" "$result" "$field_offset")
            ("mysql_fieldlen" "$result" "$field_offset")
            ("mysql_fieldtype" "$result" "$field_offset")
            ("mysql_fieldflags" "$result" "$field_offset")
            ("mysql_selectdb" "$database_name" "[$link_identifier]")
            ("mysql_freeresult" "$result")
            ("mysql_numfields" "$result")
            ("mysql_numrows" "$result")
            ("mysql_listdbs" "[$link_identifier]")
            ("mysql_listtables" "$database_name" "[$link_identifier]")
            ("mysql_listfields" "$database_name" "$table_name" "[$link_identifier]")
            ("mysql_db_name" "$result" "$row" "[$field]")
            ("mysql_dbname" "$result" "$row" "[$field]")
            ("mysql_tablename" "$result" "$row" "[$field]")
            ("mysql_table_name" "$result" "$row" "[$field]")
            ("mysqli_affected_rows" "$link")
            ("mysqli_autocommit" "$link" "$mode")
            ("mysqli_change_user" "$link" "$user" "$password" "$database")
            ("mysqli_character_set_name" "$link")
            ("mysqli_close" "$link")
            ("mysqli_commit" "$link")
            ("mysqli_connect" "[$host]" "[$user]" "[$password]" "[$database]" "[$port]" "[$socket]")
            ("mysqli_connect_errno")
            ("mysqli_connect_error")
            ("mysqli_data_seek" "$result" "$offset")
            ("mysqli_dump_debug_info" "$link")
            ("mysqli_debug" "$debug_options")
            ("mysqli_errno" "$link")
            ("mysqli_error" "$link")
            ("mysqli_stmt_execute" "$stmt")
            ("mysqli_execute" "$stmt")
            ("mysqli_fetch_field" "$result")
            ("mysqli_fetch_fields" "$result")
            ("mysqli_fetch_field_direct" "$result" "$field_nr")
            ("mysqli_fetch_lengths" "$result")
            ("mysqli_fetch_all" "$result")
            ("mysqli_fetch_array" "$result" "[$result_type]")
            ("mysqli_fetch_assoc" "$result")
            ("mysqli_fetch_object")
            ("mysqli_fetch_row" "$result")
            ("mysqli_field_count" "$link")
            ("mysqli_field_seek" "$result" "$field_nr")
            ("mysqli_field_tell" "$result")
            ("mysqli_free_result" "$result")
            ("mysqli_get_cache_stats")
            ("mysqli_get_connection_stats" "$link")
            ("mysqli_get_client_stats")
            ("mysqli_get_charset" "$link")
            ("mysqli_get_client_info" "$link")
            ("mysqli_get_client_version" "$link")
            ("mysqli_get_host_info" "$link")
            ("mysqli_get_proto_info" "$link")
            ("mysqli_get_server_info" "$link")
            ("mysqli_get_server_version" "$link")
            ("mysqli_get_warnings" "$link")
            ("mysqli_init")
            ("mysqli_info" "$link")
            ("mysqli_insert_id" "$link")
            ("mysqli_kill" "$link" "$connection_id")
            ("mysqli_more_results" "$link")
            ("mysqli_multi_query" "$link" "$query")
            ("mysqli_next_result" "$link")
            ("mysqli_num_fields" "$result")
            ("mysqli_num_rows" "$result")
            ("mysqli_options" "$link" "$option" "$value")
            ("mysqli_ping" "$link")
            ("mysqli_poll" "&$read" "&$write" "&$error" "$sec" "[$usec]")
            ("mysqli_prepare" "$link" "$query")
            ("mysqli_report" "$flags")
            ("mysqli_query" "$link" "$query")
            ("mysqli_real_connect" "$link" "[$host]" "[$user]" "[$password]" "[$database]" "[$port]" "[$socket]" "[$flags]")
            ("mysqli_real_escape_string" "$link" "$string_to_escape")
            ("mysqli_real_query" "$link" "$query")
            ("mysqli_reap_async_query" "$link")
            ("mysqli_rollback" "$link")
            ("mysqli_select_db" "$link" "$database")
            ("mysqli_set_charset" "$link" "$charset")
            ("mysqli_stmt_affected_rows" "$stmt")
            ("mysqli_stmt_attr_get" "$stmt" "$attribute")
            ("mysqli_stmt_attr_set" "$stmt" "$attribute" "$value")
            ("mysqli_stmt_bind_param" "$stmt" "$types")
            ("mysqli_stmt_bind_result" "$stmt")
            ("mysqli_stmt_close" "$stmt")
            ("mysqli_stmt_data_seek" "$stmt" "$offset")
            ("mysqli_stmt_errno" "$stmt")
            ("mysqli_stmt_error" "$stmt")
            ("mysqli_stmt_fetch" "$stmt")
            ("mysqli_stmt_field_count" "$stmt")
            ("mysqli_stmt_free_result" "$stmt")
            ("mysqli_stmt_get_result" "$stmt")
            ("mysqli_stmt_get_warnings" "$stmt")
            ("mysqli_stmt_init" "$link")
            ("mysqli_stmt_insert_id" "$stmt")
            ("mysqli_stmt_more_results" "$stmt")
            ("mysqli_stmt_next_result" "$stmt")
            ("mysqli_stmt_num_rows" "$stmt")
            ("mysqli_stmt_param_count" "$stmt")
            ("mysqli_stmt_prepare" "$stmt" "$query")
            ("mysqli_stmt_reset" "$stmt")
            ("mysqli_stmt_result_metadata" "$stmt")
            ("mysqli_stmt_send_long_data" "$stmt" "$param_nr" "$data")
            ("mysqli_stmt_store_result" "$stmt")
            ("mysqli_stmt_sqlstate" "$stmt")
            ("mysqli_sqlstate" "$link")
            ("mysqli_ssl_set" "$link" "$key" "$cert" "$certificate_authority" "$certificate_authority_path" "$cipher")
            ("mysqli_stat" "$link")
            ("mysqli_store_result" "$link")
            ("mysqli_thread_id" "$link")
            ("mysqli_thread_safe")
            ("mysqli_use_result" "$link")
            ("mysqli_warning_count" "$link")
            ("mysqli_refresh" "$link" "$options")
            ("mysqli_bind_param" "$stmt" "$types")
            ("mysqli_bind_result" "$stmt")
            ("mysqli_client_encoding")
            ("mysqli_escape_string" "$link" "$query")
            ("mysqli_fetch")
            ("mysqli_param_count")
            ("mysqli_get_metadata")
            ("mysqli_send_long_data")
            ("mysqli_set_opt")
            ("spl_classes")
            ("spl_autoload" "$class_name" "[$file_extensions]")
            ("spl_autoload_extensions" "[$file_extensions]")
            ("spl_autoload_register" "[$autoload_function]")
            ("spl_autoload_unregister" "$autoload_function")
            ("spl_autoload_functions")
            ("spl_autoload_call" "$class_name")
            ("class_parents" "$instance" "[$autoload]")
            ("class_implements" "$what" "[$autoload]")
            ("spl_object_hash" "$obj")
            ("iterator_to_array" "$iterator" "[$use_keys]")
            ("iterator_count" "$iterator")
            ("iterator_apply" "$iterator" "$function" "[$args]")
            ("pdo_drivers")
            ("posix_kill" "$pid" "$sig")
            ("posix_getpid")
            ("posix_getppid")
            ("posix_getuid")
            ("posix_setuid" "$uid")
            ("posix_geteuid")
            ("posix_seteuid" "$uid")
            ("posix_getgid")
            ("posix_setgid" "$gid")
            ("posix_getegid")
            ("posix_setegid" "$gid")
            ("posix_getgroups")
            ("posix_getlogin")
            ("posix_getpgrp")
            ("posix_setsid")
            ("posix_setpgid" "$pid" "$pgid")
            ("posix_getpgid" "$pid")
            ("posix_getsid" "$pid")
            ("posix_uname")
            ("posix_times")
            ("posix_ctermid")
            ("posix_ttyname" "$fd")
            ("posix_isatty" "$fd")
            ("posix_getcwd")
            ("posix_mkfifo" "$pathname" "$mode")
            ("posix_mknod" "$pathname" "$mode" "[$major]" "[$minor]")
            ("posix_access" "$file" "[$mode]")
            ("posix_getgrnam" "$name")
            ("posix_getgrgid" "$gid")
            ("posix_getpwnam" "$username")
            ("posix_getpwuid" "$uid")
            ("posix_getrlimit")
            ("posix_get_last_error")
            ("posix_errno")
            ("posix_strerror" "$errno")
            ("posix_initgroups" "$name" "$base_group_id")
            ("session_name" "[$name]")
            ("session_module_name" "[$module]")
            ("session_save_path" "[$path]")
            ("session_id" "[$id]")
            ("session_regenerate_id" "[$delete_old_session]")
            ("session_decode" "$data")
            ("session_register" "$name" "[$...]")
            ("session_unregister" "$name")
            ("session_is_registered" "$name")
            ("session_encode")
            ("session_start")
            ("session_destroy")
            ("session_unset")
            ("session_set_save_handler" "$open" "$close" "$read" "$write" "$destroy" "$gc")
            ("session_cache_limiter" "[$cache_limiter]")
            ("session_cache_expire" "[$new_cache_expire]")
            ("session_set_cookie_params" "$lifetime" "[$path]" "[$domain]" "[$secure]" "[$httponly]")
            ("session_get_cookie_params")
            ("session_write_close")
            ("session_commit")
            ("shmop_open" "$key" "$flags" "$mode" "$size")
            ("shmop_read" "$shmid" "$start" "$count")
            ("shmop_close" "$shmid")
            ("shmop_size" "$shmid")
            ("shmop_write" "$shmid" "$data" "$offset")
            ("shmop_delete" "$shmid")
            ("simplexml_load_file" "$filename" "[$class_name]" "[$options]" "[$ns]" "[$is_prefix]")
            ("simplexml_load_string" "$data" "[$class_name]" "[$options]" "[$ns]" "[$is_prefix]")
            ("simplexml_import_dom" "$node" "[$class_name]")
            ("use_soap_error_handler" "[$handler]")
            ("is_soap_fault" "$object")
            ("socket_select" "&$read_fds" "&$write_fds" "&$except_fds" "$tv_sec" "[$tv_usec]")
            ("socket_create" "$domain" "$type" "$protocol")
            ("socket_create_listen" "$port" "[$backlog]")
            ("socket_create_pair" "$domain" "$type" "$protocol" "&$fd")
            ("socket_accept" "$socket")
            ("socket_set_nonblock" "$socket")
            ("socket_set_block" "$socket")
            ("socket_listen" "$socket" "[$backlog]")
            ("socket_close" "$socket")
            ("socket_write" "$socket" "$buf" "[$length]")
            ("socket_read" "$socket" "$length" "[$type]")
            ("socket_getsockname" "$socket" "&$addr" "[&$port]")
            ("socket_getpeername" "$socket" "&$addr" "[&$port]")
            ("socket_connect" "$socket" "$addr" "[$port]")
            ("socket_strerror" "$errno")
            ("socket_bind" "$socket" "$addr" "[$port]")
            ("socket_recv" "$socket" "&$buf" "$len" "$flags")
            ("socket_send" "$socket" "$buf" "$len" "$flags")
            ("socket_recvfrom" "$socket" "&$buf" "$len" "$flags" "&$name" "[&$port]")
            ("socket_sendto" "$socket" "$buf" "$len" "$flags" "$addr" "[$port]")
            ("socket_get_option" "$socket" "$level" "$optname")
            ("socket_set_option" "$socket" "$level" "$optname" "$optval")
            ("socket_shutdown" "$socket" "[$how]")
            ("socket_last_error" "[$socket]")
            ("socket_clear_error" "[$socket]")
            ("socket_getopt" "$socket" "$level" "$optname")
            ("socket_setopt" "$socket" "$level" "$optname" "$optval")
            ("constant" "$const_name")
            ("bin2hex" "$data")
            ("sleep" "$seconds")
            ("usleep" "$micro_seconds")
            ("time_nanosleep" "$seconds" "$nanoseconds")
            ("time_sleep_until" "$timestamp")
            ("strptime" "$timestamp" "$format")
            ("flush")
            ("wordwrap" "$str" "[$width]" "[$break]" "[$cut]")
            ("htmlspecialchars" "$string" "[$quote_style]" "[$charset]" "[$double_encode]")
            ("htmlentities" "$string" "[$quote_style]" "[$charset]" "[$double_encode]")
            ("html_entity_decode" "$string" "[$quote_style]" "[$charset]")
            ("htmlspecialchars_decode" "$string" "[$quote_style]")
            ("get_html_translation_table" "[$table]" "[$quote_style]")
            ("sha1" "$str" "[$raw_output]")
            ("sha1_file" "$filename" "[$raw_output]")
            ("md5" "$str" "[$raw_output]")
            ("md5_file" "$filename" "[$raw_output]")
            ("crc32" "$str")
            ("iptcparse" "$iptcdata")
            ("iptcembed" "$iptcdata" "$jpeg_file_name" "[$spool]")
            ("getimagesize" "$imagefile" "[&$info]")
            ("image_type_to_mime_type" "$imagetype")
            ("image_type_to_extension" "$imagetype" "[$include_dot]")
            ("phpinfo" "[$what]")
            ("phpversion" "[$extension]")
            ("phpcredits" "[$flag]")
            ("php_logo_guid")
            ("php_real_logo_guid")
            ("php_egg_logo_guid")
            ("zend_logo_guid")
            ("php_sapi_name")
            ("php_uname")
            ("php_ini_scanned_files")
            ("php_ini_loaded_file")
            ("strnatcmp" "$s1" "$s2")
            ("strnatcasecmp" "$s1" "$s2")
            ("substr_count" "$haystack" "$needle" "[$offset]" "[$length]")
            ("strspn" "$str" "$mask" "[$start]" "[$len]")
            ("strcspn" "$str" "$mask" "[$start]" "[$len]")
            ("strtok" "$str" "$token")
            ("strtoupper" "$str")
            ("strtolower" "$str")
            ("strpos" "$haystack" "$needle" "[$offset]")
            ("stripos" "$haystack" "$needle" "[$offset]")
            ("strrpos" "$haystack" "$needle" "[$offset]")
            ("strripos" "$haystack" "$needle" "[$offset]")
            ("strrev" "$str")
            ("hebrev" "$str" "[$max_chars_per_line]")
            ("hebrevc" "$str" "[$max_chars_per_line]")
            ("nl2br" "$str" "[$is_xhtml]")
            ("basename" "$path" "[$suffix]")
            ("dirname" "$path")
            ("pathinfo" "$path" "[$options]")
            ("stripslashes" "$str")
            ("stripcslashes" "$str")
            ("strstr" "$haystack" "$needle" "[$part]")
            ("stristr" "$haystack" "$needle" "[$part]")
            ("strrchr" "$haystack" "$needle")
            ("str_shuffle" "$str")
            ("str_word_count" "$str" "[$format]" "[$charlist]")
            ("str_split" "$str" "[$split_length]")
            ("strpbrk" "$haystack" "[$char_list]")
            ("substr_compare" "$main_str" "$str" "$offset" "[$length]" "[$case_sensitivity]")
            ("strcoll" "$str1" "$str2")
            ("money_format" "$format" "$value")
            ("substr" "$str" "$start" "[$length]")
            ("substr_replace" "$str" "$replace" "$start" "[$length]")
            ("quotemeta" "$str")
            ("ucfirst" "$str")
            ("lcfirst" "$str")
            ("ucwords" "$str")
            ("strtr" "$str" "$from" "[$to]")
            ("addslashes" "$str")
            ("addcslashes" "$str" "$charlist")
            ("rtrim" "$str" "[$character_mask]")
            ("str_replace" "$search" "$replace" "$subject" "[&$replace_count]")
            ("str_ireplace" "$search" "$replace" "$subject" "[&$replace_count]")
            ("str_repeat" "$input" "$mult")
            ("count_chars" "$input" "[$mode]")
            ("chunk_split" "$str" "[$chunklen]" "[$ending]")
            ("trim" "$str" "[$character_mask]")
            ("ltrim" "$str" "[$character_mask]")
            ("strip_tags" "$str" "[$allowable_tags]")
            ("similar_text" "$str1" "$str2" "[&$percent]")
            ("explode" "$separator" "$str" "[$limit]")
            ("implode" "$glue" "$pieces")
            ("join" "$glue" "$pieces")
            ("setlocale" "$category" "$locale" "[$...]")
            ("localeconv")
            ("nl_langinfo" "$item")
            ("soundex" "$str")
            ("levenshtein" "$str1" "$str2" "$cost_ins" "$cost_rep" "$cost_del")
            ("chr" "$codepoint")
            ("ord" "$character")
            ("parse_str" "$encoded_string" "[&$result]")
            ("str_getcsv" "$string" "[$delimiter]" "[$enclosure]" "[$escape]")
            ("str_pad" "$input" "$pad_length" "[$pad_string]" "[$pad_type]")
            ("chop" "$str" "[$character_mask]")
            ("strchr" "$haystack" "$needle" "[$part]")
            ("sprintf" "$format" "$arg1" "[$...]")
            ("printf" "$format" "[$arg1]" "[$...]")
            ("vprintf" "$format" "$args")
            ("vsprintf" "$format" "$args")
            ("fprintf" "$stream" "$format" "[$arg1]" "[$...]")
            ("vfprintf" "$stream" "$format" "$args")
            ("sscanf" "$str" "$format" "[&$...]")
            ("fscanf" "$stream" "$format" "[&$...]")
            ("parse_url" "$url" "[$component]")
            ("urlencode" "$str")
            ("urldecode" "$str")
            ("rawurlencode" "$str")
            ("rawurldecode" "$str")
            ("http_build_query" "$formdata" "[$prefix]" "[$arg_separator]")
            ("readlink" "$filename")
            ("linkinfo" "$filename")
            ("symlink" "$target" "$link")
            ("link" "$target" "$link")
            ("unlink" "$filename" "[$context]")
            ("exec" "$command" "[&$output]" "[&$return_value]")
            ("system" "$command" "[&$return_value]")
            ("escapeshellcmd" "$command")
            ("escapeshellarg" "$arg")
            ("passthru" "$command" "[&$return_value]")
            ("shell_exec" "$cmd")
            ("proc_open" "$command" "$descriptorspec" "&$pipes" "[$cwd]" "[$env]" "[$other_options]")
            ("proc_close" "$process")
            ("proc_terminate" "$process" "[$signal]")
            ("proc_get_status" "$process")
            ("proc_nice" "$priority")
            ("rand" "[$min]" "[$max]")
            ("srand" "[$seed]")
            ("getrandmax")
            ("mt_rand" "[$min]" "[$max]")
            ("mt_srand" "[$seed]")
            ("mt_getrandmax")
            ("getservbyname" "$service" "$protocol")
            ("getservbyport" "$port" "$protocol")
            ("getprotobyname" "$name")
            ("getprotobynumber" "$proto")
            ("getmyuid")
            ("getmygid")
            ("getmypid")
            ("getmyinode")
            ("getlastmod")
            ("base64_decode" "$str" "[$strict]")
            ("base64_encode" "$str")
            ("convert_uuencode" "$data")
            ("convert_uudecode" "$data")
            ("abs" "$number")
            ("ceil" "$number")
            ("floor" "$number")
            ("round" "$number" "[$precision]" "[$mode]")
            ("sin" "$number")
            ("cos" "$number")
            ("tan" "$number")
            ("asin" "$number")
            ("acos" "$number")
            ("atan" "$number")
            ("atanh" "$number")
            ("atan2" "$y" "$x")
            ("sinh" "$number")
            ("cosh" "$number")
            ("tanh" "$number")
            ("asinh" "$number")
            ("acosh" "$number")
            ("expm1" "$number")
            ("log1p" "$number")
            ("pi")
            ("is_finite" "$val")
            ("is_nan" "$val")
            ("is_infinite" "$val")
            ("pow" "$base" "$exponent")
            ("exp" "$number")
            ("log" "$number" "[$base]")
            ("log10" "$number")
            ("sqrt" "$number")
            ("hypot" "$num1" "$num2")
            ("deg2rad" "$number")
            ("rad2deg" "$number")
            ("bindec" "$binary_number")
            ("hexdec" "$hexadecimal_number")
            ("octdec" "$octal_number")
            ("decbin" "$decimal_number")
            ("decoct" "$decimal_number")
            ("dechex" "$decimal_number")
            ("base_convert" "$number" "$frombase" "$tobase")
            ("number_format" "$number" "[$num_decimal_places]" "[$dec_seperator]" "[$thousands_seperator]")
            ("fmod" "$x" "$y")
            ("inet_ntop" "$in_addr")
            ("inet_pton" "$ip_address")
            ("ip2long" "$ip_address")
            ("long2ip" "$proper_address")
            ("getenv" "$varname")
            ("putenv" "$setting")
            ("getopt" "$options" "[$opts]")
            ("sys_getloadavg")
            ("microtime" "[$get_as_float]")
            ("gettimeofday" "[$get_as_float]")
            ("getrusage" "[$who]")
            ("uniqid" "[$prefix]" "[$more_entropy]")
            ("quoted_printable_decode" "$str")
            ("quoted_printable_encode" "$str")
            ("convert_cyr_string" "$str" "$from" "$to")
            ("get_current_user")
            ("set_time_limit" "$seconds")
            ("get_cfg_var" "$option_name")
            ("magic_quotes_runtime" "$new_setting")
            ("set_magic_quotes_runtime" "$new_setting")
            ("get_magic_quotes_gpc")
            ("get_magic_quotes_runtime")
            ("import_request_variables" "$types" "[$prefix]")
            ("error_log" "$message" "[$message_type]" "[$destination]" "[$extra_headers]")
            ("error_get_last")
            ("call_user_func" "$function_name" "[$parmeter]" "[$...]")
            ("call_user_func_array" "$function_name" "$parameters")
            ("call_user_method" "$method_name" "&$object" "[$parameter]" "[$...]")
            ("call_user_method_array" "$method_name" "&$object" "$params")
            ("forward_static_call" "$function_name" "[$parameter]" "[$...]")
            ("forward_static_call_array" "$function_name" "$parameters")
            ("serialize" "$var")
            ("unserialize" "$variable_representation")
            ("var_dump" "$var" "[$...]")
            ("var_export" "$var" "[$return]")
            ("debug_zval_dump" "$var" "[$...]")
            ("print_r" "$var" "[$return]")
            ("memory_get_usage" "[$real_usage]")
            ("memory_get_peak_usage" "[$real_usage]")
            ("register_shutdown_function" "$function_name")
            ("register_tick_function" "$function_name" "[$arg]" "[$...]")
            ("unregister_tick_function" "$function_name")
            ("highlight_file" "$file_name" "[$return]")
            ("show_source" "$file_name" "[$return]")
            ("highlight_string" "$string" "[$return]")
            ("php_strip_whitespace" "$file_name")
            ("ini_get" "$varname")
            ("ini_get_all" "[$extension]")
            ("ini_set" "$varname" "$newvalue")
            ("ini_alter" "$varname" "$newvalue")
            ("ini_restore" "$varname")
            ("get_include_path")
            ("set_include_path" "$new_include_path")
            ("restore_include_path")
            ("setcookie" "$name" "[$value]" "[$expires]" "[$path]" "[$domain]" "[$secure]")
            ("setrawcookie" "$name" "[$value]" "[$expires]" "[$path]" "[$domain]" "[$secure]")
            ("header" "$header" "[$replace]" "[$http_response_code]")
            ("header_remove" "[$name]")
            ("headers_sent" "[&$file]" "[&$line]")
            ("headers_list")
            ("connection_aborted")
            ("connection_status")
            ("ignore_user_abort" "[$value]")
            ("parse_ini_file" "$filename" "[$process_sections]" "[$scanner_mode]")
            ("parse_ini_string" "$ini_string" "[$process_sections]" "[$scanner_mode]")
            ("is_uploaded_file" "$path")
            ("move_uploaded_file" "$path" "$new_path")
            ("gethostbyaddr" "$ip_address")
            ("gethostbyname" "$hostname")
            ("gethostbynamel" "$hostname")
            ("gethostname")
            ("dns_check_record" "$host" "[$type]")
            ("checkdnsrr" "$host" "[$type]")
            ("dns_get_mx" "$hostname" "&$mxhosts" "[&$weight]")
            ("getmxrr" "$hostname" "&$mxhosts" "[&$weight]")
            ("dns_get_record" "$hostname" "[$type]" "[&$authns]" "[&$addtl]")
            ("intval" "$var" "[$base]")
            ("floatval" "$var")
            ("doubleval" "$var")
            ("strval" "$var")
            ("gettype" "$var")
            ("settype" "&$var" "$type")
            ("is_null" "$var")
            ("is_resource" "$var")
            ("is_bool" "$var")
            ("is_long" "$var")
            ("is_float" "$var")
            ("is_int" "$var")
            ("is_integer" "$var")
            ("is_double" "$var")
            ("is_real" "$var")
            ("is_numeric" "$value")
            ("is_string" "$var")
            ("is_array" "$var")
            ("is_object" "$var")
            ("is_scalar" "$value")
            ("is_callable" "$var" "[$syntax_only]" "[&$callable_name]")
            ("pclose" "$fp")
            ("popen" "$command" "$mode")
            ("readfile" "$filename" "[$flags]" "[$context]")
            ("rewind" "$fp")
            ("rmdir" "$dirname" "[$context]")
            ("umask" "[$mask]")
            ("fclose" "$fp")
            ("feof" "$fp")
            ("fgetc" "$fp")
            ("fgets" "$fp" "[$length]")
            ("fgetss" "$fp" "[$length]" "[$allowable_tags]")
            ("fread" "$fp" "$length")
            ("fopen" "$filename" "$mode" "[$use_include_path]" "[$context]")
            ("fpassthru" "$fp")
            ("ftruncate" "$fp" "$size")
            ("fstat" "$fp")
            ("fseek" "$fp" "$offset" "[$whence]")
            ("ftell" "$fp")
            ("fflush" "$fp")
            ("fwrite" "$fp" "$str" "[$length]")
            ("fputs" "$fp" "$str" "[$length]")
            ("mkdir" "$pathname" "[$mode]" "[$recursive]" "[$context]")
            ("rename" "$old_name" "$new_name" "[$context]")
            ("copy" "$source_file" "$destination_file" "[$context]")
            ("tempnam" "$dir" "$prefix")
            ("tmpfile")
            ("file" "$filename" "[$flags]" "[$context]")
            ("file_get_contents" "$filename" "[$flags]" "[$context]" "[$offset]" "[$maxlen]")
            ("file_put_contents" "$filename" "$data" "[$flags]" "[$context]")
            ("stream_select" "&$read_streams" "&$write_streams" "&$except_streams" "$tv_sec" "[$tv_usec]")
            ("stream_context_create" "[$options]" "[$params]")
            ("stream_context_set_params" "$stream_or_context" "$options")
            ("stream_context_get_params" "$stream_or_context")
            ("stream_context_set_option" "$stream_or_context" "$wrappername" "$optionname" "$value")
            ("stream_context_get_options" "$stream_or_context")
            ("stream_context_get_default" "[$options]")
            ("stream_context_set_default" "$options")
            ("stream_filter_prepend" "$stream" "$filtername" "[$read_write]" "[$filterparams]")
            ("stream_filter_append" "$stream" "$filtername" "[$read_write]" "[$filterparams]")
            ("stream_filter_remove" "$stream_filter")
            ("stream_socket_client" "$remoteaddress" "[&$errcode]" "[&$errstring]" "[$timeout]" "[$flags]" "[$context]")
            ("stream_socket_server" "$localaddress" "[&$errcode]" "[&$errstring]" "[$flags]" "[$context]")
            ("stream_socket_accept" "$serverstream" "[$timeout]" "[&$peername]")
            ("stream_socket_get_name" "$stream" "$want_peer")
            ("stream_socket_recvfrom" "$stream" "$amount" "[$flags]" "[&$remote_addr]")
            ("stream_socket_sendto" "$stream" "$data" "[$flags]" "[$target_addr]")
            ("stream_socket_enable_crypto" "$stream" "$enable" "[$cryptokind]" "[$sessionstream]")
            ("stream_socket_shutdown" "$stream" "$how")
            ("stream_socket_pair" "$domain" "$type" "$protocol")
            ("stream_copy_to_stream" "$source" "$dest" "[$maxlen]" "[$pos]")
            ("stream_get_contents" "$source" "[$maxlen]" "[$offset]")
            ("stream_supports_lock" "$stream")
            ("fgetcsv" "$fp" "[$length]" "[$delimiter]" "[$enclosure]" "[$escape]")
            ("fputcsv" "$fp" "$fields" "[$delimiter]" "[$enclosure]")
            ("flock" "$fp" "$operation" "[&$wouldblock]")
            ("get_meta_tags" "$filename" "[$use_include_path]")
            ("stream_set_read_buffer" "$fp" "$buffer")
            ("stream_set_write_buffer" "$fp" "$buffer")
            ("set_file_buffer" "$fp" "$buffer")
            ("set_socket_blocking" "$socket" "$mode")
            ("stream_set_blocking" "$socket" "$mode")
            ("socket_set_blocking" "$socket" "$mode")
            ("stream_get_meta_data" "$fp")
            ("stream_get_line" "$stream" "$maxlen" "[$ending]")
            ("stream_wrapper_register" "$protocol" "$classname" "[$flags]")
            ("stream_register_wrapper" "$protocol" "$classname" "[$flags]")
            ("stream_wrapper_unregister" "$protocol")
            ("stream_wrapper_restore" "$protocol")
            ("stream_get_wrappers")
            ("stream_get_transports")
            ("stream_resolve_include_path" "$filename")
            ("stream_is_local" "$stream")
            ("get_headers" "$url" "[$format]")
            ("stream_set_timeout" "$stream" "$seconds" "$microseconds")
            ("socket_set_timeout" "$stream" "$seconds" "$microseconds")
            ("socket_get_status" "$fp")
            ("realpath" "$path")
            ("fnmatch" "$pattern" "$filename" "[$flags]")
            ("fsockopen" "$hostname" "$port" "[&$errno]" "[&$errstr]" "[$timeout]")
            ("pfsockopen" "$hostname" "$port" "[&$errno]" "[&$errstr]" "[$timeout]")
            ("pack" "$format" "$arg1" "[$...]")
            ("unpack" "$format" "$input")
            ("get_browser" "[$browser_name]" "[$return_array]")
            ("crypt" "$str" "[$salt]")
            ("opendir" "$path" "[$context]")
            ("closedir" "[$dir_handle]")
            ("chdir" "$directory")
            ("getcwd")
            ("rewinddir" "[$dir_handle]")
            ("readdir" "[$dir_handle]")
            ("dir" "$directory" "[$context]")
            ("scandir" "$dir" "[$sorting_order]" "[$context]")
            ("glob" "$pattern" "[$flags]")
            ("fileatime" "$filename")
            ("filectime" "$filename")
            ("filegroup" "$filename")
            ("fileinode" "$filename")
            ("filemtime" "$filename")
            ("fileowner" "$filename")
            ("fileperms" "$filename")
            ("filesize" "$filename")
            ("filetype" "$filename")
            ("file_exists" "$filename")
            ("is_writable" "$filename")
            ("is_writeable" "$filename")
            ("is_readable" "$filename")
            ("is_executable" "$filename")
            ("is_file" "$filename")
            ("is_dir" "$filename")
            ("is_link" "$filename")
            ("stat" "$filename")
            ("lstat" "$filename")
            ("chown" "$filename" "$user")
            ("chgrp" "$filename" "$group")
            ("lchown" "$filename" "$user")
            ("lchgrp" "$filename" "$group")
            ("chmod" "$filename" "$mode")
            ("touch" "$filename" "[$time]" "[$atime]")
            ("clearstatcache" "[$clear_realpath_cache]" "[$filename]")
            ("disk_total_space" "$path")
            ("disk_free_space" "$path")
            ("diskfreespace" "$path")
            ("realpath_cache_size")
            ("realpath_cache_get")
            ("mail" "$to" "$subject" "$message" "[$additional_headers]" "[$additional_parameters]")
            ("ezmlm_hash" "$addr")
            ("openlog" "$ident" "$option" "$facility")
            ("syslog" "$priority" "$message")
            ("closelog")
            ("define_syslog_variables")
            ("lcg_value")
            ("metaphone" "$text" "[$phones]")
            ("ob_start" "[$user_function]" "[$chunk_size]" "[$flags]")
            ("ob_flush")
            ("ob_clean")
            ("ob_end_flush")
            ("ob_end_clean")
            ("ob_get_flush")
            ("ob_get_clean")
            ("ob_get_length")
            ("ob_get_level")
            ("ob_get_status" "[$full_status]")
            ("ob_get_contents")
            ("ob_implicit_flush" "[$flag]")
            ("ob_list_handlers")
            ("ksort" "&$arg" "[$sort_flags]")
            ("krsort" "&$arg" "[$sort_flags]")
            ("natsort" "&$arg")
            ("natcasesort" "&$arg")
            ("asort" "&$arg" "[$sort_flags]")
            ("arsort" "&$arg" "[$sort_flags]")
            ("sort" "&$arg" "[$sort_flags]")
            ("rsort" "&$arg" "[$sort_flags]")
            ("usort" "&$arg" "$cmp_function")
            ("uasort" "&$arg" "$cmp_function")
            ("uksort" "&$arg" "$cmp_function")
            ("shuffle" "&$arg")
            ("array_walk" "&$input" "$funcname" "[$userdata]")
            ("array_walk_recursive" "&$input" "$funcname" "[$userdata]")
            ("count" "$var" "[$mode]")
            ("end" "&$arg")
            ("prev" "&$arg")
            ("next" "&$arg")
            ("reset" "&$arg")
            ("current" "&$arg")
            ("key" "&$arg")
            ("min" "$arg1" "[$arg2]" "[$...]")
            ("max" "$arg1" "[$arg2]" "[$...]")
            ("in_array" "$needle" "$haystack" "[$strict]")
            ("array_search" "$needle" "$haystack" "[$strict]")
            ("extract" "&$arg" "[$extract_type]" "[$prefix]")
            ("compact" "$var_names" "[$...]")
            ("array_fill" "$start_key" "$num" "$val")
            ("array_fill_keys" "$keys" "$val")
            ("range" "$low" "$high" "[$step]")
            ("array_multisort" "&$arr1" "[&$SORT_ASC_or_SORT_DESC]" "[&$SORT_REGULAR_or_SORT_NUMERIC_or_SORT_STRING]" "[&$arr2]" "[&$SORT_ASC_or_SORT_DESC]" "[&$SORT_REGULAR_or_SORT_NUMERIC_or_SORT_STRING]")
            ("array_push" "&$stack" "$var" "[$...]")
            ("array_pop" "&$stack")
            ("array_shift" "&$stack")
            ("array_unshift" "&$stack" "$var" "[$...]")
            ("array_splice" "&$arg" "$offset" "[$length]" "[$replacement]")
            ("array_slice" "$arg" "$offset" "[$length]" "[$preserve_keys]")
            ("array_merge" "$arr1" "$arr2" "[$...]")
            ("array_merge_recursive" "$arr1" "$arr2" "[$...]")
            ("array_replace" "$arr1" "$arr2" "[$...]")
            ("array_replace_recursive" "$arr1" "$arr2" "[$...]")
            ("array_keys" "$arg" "[$search_value]" "[$strict]")
            ("array_values" "$arg")
            ("array_count_values" "$arg")
            ("array_reverse" "$input" "[$preserve_keys]")
            ("array_reduce" "$arg" "$callback" "[$initial]")
            ("array_pad" "$arg" "$pad_size" "$pad_value")
            ("array_flip" "$arg")
            ("array_change_key_case" "$input" "[$case]")
            ("array_rand" "$arg" "[$num_req]")
            ("array_unique" "$arg")
            ("array_intersect" "$arr1" "$arr2" "[$...]")
            ("array_intersect_key" "$arr1" "$arr2" "[$...]")
            ("array_intersect_ukey" "$arr1" "$arr2" "$callback_key_compare_func")
            ("array_uintersect" "$arr1" "$arr2" "$callback_data_compare_func")
            ("array_intersect_assoc" "$arr1" "$arr2" "[$...]")
            ("array_uintersect_assoc" "$arr1" "$arr2" "$callback_data_compare_func")
            ("array_intersect_uassoc" "$arr1" "$arr2" "$callback_key_compare_func")
            ("array_uintersect_uassoc" "$arr1" "$arr2" "$callback_data_compare_func" "$callback_key_compare_func")
            ("array_diff" "$arr1" "$arr2" "[$...]")
            ("array_diff_key" "$arr1" "$arr2" "[$...]")
            ("array_diff_ukey" "$arr1" "$arr2" "$callback_key_comp_func")
            ("array_udiff" "$arr1" "$arr2" "$callback_data_comp_func")
            ("array_diff_assoc" "$arr1" "$arr2" "[$...]")
            ("array_udiff_assoc" "$arr1" "$arr2" "$callback_key_comp_func")
            ("array_diff_uassoc" "$arr1" "$arr2" "$callback_data_comp_func")
            ("array_udiff_uassoc" "$arr1" "$arr2" "$callback_data_comp_func" "$callback_key_comp_func")
            ("array_sum" "$arg")
            ("array_product" "$arg")
            ("array_filter" "$arg" "[$callback]")
            ("array_map" "$callback" "$arg" "[$...]")
            ("array_chunk" "$arg" "$size" "[$preserve_keys]")
            ("array_combine" "$keys" "$values")
            ("array_key_exists" "$key" "$search")
            ("pos" "&$arg")
            ("sizeof" "$var" "[$mode]")
            ("key_exists" "$key" "$search")
            ("assert" "$assertion")
            ("assert_options" "$what" "[$value]")
            ("version_compare" "$ver1" "$ver2" "[$oper]")
            ("ftok" "$pathname" "$proj")
            ("str_rot13" "$str")
            ("stream_get_filters")
            ("stream_filter_register" "$filtername" "$classname")
            ("stream_bucket_make_writeable" "$brigade")
            ("stream_bucket_prepend" "$brigade" "$bucket")
            ("stream_bucket_append" "$brigade" "$bucket")
            ("stream_bucket_new" "$stream" "$buffer")
            ("output_add_rewrite_var" "$name" "$value")
            ("output_reset_rewrite_vars")
            ("sys_get_temp_dir")
            ("sybase_connect" "[$host]" "[$user]" "[$password]" "[$charset]" "[$appname]" "[$new]")
            ("sybase_pconnect" "[$host]" "[$user]" "[$password]" "[$charset]" "[$appname]")
            ("sybase_close" "[$link_id]")
            ("sybase_select_db" "$database" "[$link_id]")
            ("sybase_query" "$query" "[$link_id]")
            ("sybase_unbuffered_query" "$query" "[$link_id]")
            ("sybase_free_result" "$result")
            ("sybase_get_last_message" "$d")
            ("sybase_num_rows" "$result")
            ("sybase_num_fields" "$result")
            ("sybase_fetch_row" "$result")
            ("sybase_fetch_array" "$result")
            ("sybase_fetch_assoc" "$result")
            ("sybase_fetch_object" "$result" "[$object]")
            ("sybase_data_seek" "$result" "$offset")
            ("sybase_fetch_field" "$result" "[$offset]")
            ("sybase_field_seek" "$result" "$offset")
            ("sybase_result" "$result" "$row" "$field")
            ("sybase_affected_rows" "[$link_id]")
            ("sybase_min_client_severity" "$severity")
            ("sybase_min_server_severity" "$severity")
            ("sybase_set_message_handler" "$error_func" "[$connection]")
            ("sybase_deadlock_retry_count" "$retry_count")
            ("sem_get" "$key" "[$max_acquire]" "[$perm]" "[$auto_release]")
            ("sem_acquire" "$sem_identifier")
            ("sem_release" "$sem_identifier")
            ("sem_remove" "$sem_identifier")
            ("shm_attach" "$key" "[$memsize]" "[$perm]")
            ("shm_remove" "$shm_identifier")
            ("shm_detach" "$shm_identifier")
            ("shm_put_var" "$shm_identifier" "$variable_key" "$variable")
            ("shm_has_var" "$id" "$variable_key")
            ("shm_get_var" "$id" "$variable_key")
            ("shm_remove_var" "$id" "$variable_key")
            ("token_get_all" "$source")
            ("token_name" "$token")
            ("wddx_serialize_value" "$var" "[$comment]")
            ("wddx_serialize_vars" "$var_name" "[$...]")
            ("wddx_packet_start" "[$comment]")
            ("wddx_packet_end" "$packet_id")
            ("wddx_add_vars" "$packet_id" "$var_name" "[$...]")
            ("wddx_deserialize" "$packet")
            ("xml_parser_create" "[$encoding]")
            ("xml_parser_create_ns" "[$encoding]" "[$sep]")
            ("xml_set_object" "$parser" "&$obj")
            ("xml_set_element_handler" "$parser" "$shdl" "$ehdl")
            ("xml_set_character_data_handler" "$parser" "$hdl")
            ("xml_set_processing_instruction_handler" "$parser" "$hdl")
            ("xml_set_default_handler" "$parser" "$hdl")
            ("xml_set_unparsed_entity_decl_handler" "$parser" "$hdl")
            ("xml_set_notation_decl_handler" "$parser" "$hdl")
            ("xml_set_external_entity_ref_handler" "$parser" "$hdl")
            ("xml_set_start_namespace_decl_handler" "$parser" "$hdl")
            ("xml_set_end_namespace_decl_handler" "$parser" "$hdl")
            ("xml_parse" "$parser" "$data" "[$isfinal]")
            ("xml_parse_into_struct" "$parser" "$data" "&$values" "[&$index]")
            ("xml_get_error_code" "$parser")
            ("xml_error_string" "$code")
            ("xml_get_current_line_number" "$parser")
            ("xml_get_current_column_number" "$parser")
            ("xml_get_current_byte_index" "$parser")
            ("xml_parser_free" "$parser")
            ("xml_parser_set_option" "$parser" "$option" "$value")
            ("xml_parser_get_option" "$parser" "$option")
            ("utf8_encode" "$data")
            ("utf8_decode" "$data")
            ("xmlwriter_open_uri" "$uri")
            ("xmlwriter_open_memory")
            ("xmlwriter_set_indent" "$xmlwriter" "$indent")
            ("xmlwriter_set_indent_string" "$xmlwriter" "$indentString")
            ("xmlwriter_start_comment" "$xmlwriter")
            ("xmlwriter_end_comment" "$xmlwriter")
            ("xmlwriter_start_attribute" "$xmlwriter" "$name")
            ("xmlwriter_end_attribute" "$xmlwriter")
            ("xmlwriter_write_attribute" "$xmlwriter" "$name" "$value")
            ("xmlwriter_start_attribute_ns" "$xmlwriter" "$prefix" "$name" "$uri")
            ("xmlwriter_write_attribute_ns" "$xmlwriter" "$prefix" "$name" "$uri" "$content")
            ("xmlwriter_start_element" "$xmlwriter" "$name")
            ("xmlwriter_end_element" "$xmlwriter")
            ("xmlwriter_full_end_element" "$xmlwriter")
            ("xmlwriter_start_element_ns" "$xmlwriter" "$prefix" "$name" "$uri")
            ("xmlwriter_write_element" "$xmlwriter" "$name" "[$content]")
            ("xmlwriter_write_element_ns" "$xmlwriter" "$prefix" "$name" "$uri" "[$content]")
            ("xmlwriter_start_pi" "$xmlwriter" "$target")
            ("xmlwriter_end_pi" "$xmlwriter")
            ("xmlwriter_write_pi" "$xmlwriter" "$target" "$content")
            ("xmlwriter_start_cdata" "$xmlwriter")
            ("xmlwriter_end_cdata" "$xmlwriter")
            ("xmlwriter_write_cdata" "$xmlwriter" "$content")
            ("xmlwriter_text" "$xmlwriter" "$content")
            ("xmlwriter_write_raw" "$xmlwriter" "$content")
            ("xmlwriter_start_document" "$xmlwriter" "[$version]" "[$encoding]" "[$standalone]")
            ("xmlwriter_end_document" "$xmlwriter")
            ("xmlwriter_write_comment" "$xmlwriter" "$content")
            ("xmlwriter_start_dtd" "$xmlwriter" "$qualifiedName" "[$publicId]" "[$systemId]")
            ("xmlwriter_end_dtd" "$xmlwriter")
            ("xmlwriter_write_dtd" "$xmlwriter" "$name" "[$publicId]" "[$systemId]" "[$subset]")
            ("xmlwriter_start_dtd_element" "$xmlwriter" "$qualifiedName")
            ("xmlwriter_end_dtd_element" "$xmlwriter")
            ("xmlwriter_write_dtd_element" "$xmlwriter" "$name" "$content")
            ("xmlwriter_start_dtd_attlist" "$xmlwriter" "$name")
            ("xmlwriter_end_dtd_attlist" "$xmlwriter")
            ("xmlwriter_write_dtd_attlist" "$xmlwriter" "$name" "$content")
            ("xmlwriter_start_dtd_entity" "$xmlwriter" "$name" "$isparam")
            ("xmlwriter_end_dtd_entity" "$xmlwriter")
            ("xmlwriter_write_dtd_entity" "$xmlwriter" "$name" "$content")
            ("xmlwriter_output_memory" "$xmlwriter" "[$flush]")
            ("xmlwriter_flush" "$xmlwriter" "[$empty]")
            ("apache_lookup_uri" "$filename")
            ("virtual" "$uri")
            ("apache_request_headers")
            ("apache_response_headers")
            ("apache_setenv" "$variable" "$value" "[$walk_to_top]")
            ("apache_getenv" "$variable" "[$walk_to_top]")
            ("apache_note" "$note_name" "[$note_value]")
            ("apache_get_version")
            ("apache_get_modules")
            ("getallheaders")
            ("zip_open" "$filename")
            ("zip_close" "$zip")
            ("zip_read" "$zip")
            ("zip_entry_open" "$zip_dp" "$zip_entry" "[$mode]")
            ("zip_entry_close" "$zip_ent")
            ("zip_entry_read" "$zip_entry" "[$len]")
            ("zip_entry_filesize" "$zip_entry")
            ("zip_entry_name" "$zip_entry")
            ("zip_entry_compressedsize" "$zip_entry")
            ("zip_entry_compressionmethod" "$zip_entry")
            ("sqlite_open" "$filename" "[$mode]" "[&$error_message]")
            ("sqlite_popen" "$filename" "[$mode]" "[&$error_message]")
            ("sqlite_close" "$db")
            ("sqlite_query" "$query" "$db" "[$result_type]" "[&$error_message]")
            ("sqlite_exec" "$query" "$db" "[&$error_message]")
            ("sqlite_array_query" "$db" "$query" "[$result_type]" "[$decode_binary]")
            ("sqlite_single_query" "$db" "$query" "[$first_row_only]" "[$decode_binary]")
            ("sqlite_fetch_array" "$result" "[$result_type]" "[$decode_binary]")
            ("sqlite_fetch_object" "$result" "[$class_name]" "[$ctor_params]" "[$decode_binary]")
            ("sqlite_fetch_single" "$result" "[$decode_binary]")
            ("sqlite_fetch_string" "$result" "[$decode_binary]")
            ("sqlite_fetch_all" "$result" "[$result_type]" "[$decode_binary]")
            ("sqlite_current" "$result" "[$result_type]" "[$decode_binary]")
            ("sqlite_column" "$result" "$index_or_name" "[$decode_binary]")
            ("sqlite_libversion")
            ("sqlite_libencoding")
            ("sqlite_changes" "$db")
            ("sqlite_last_insert_rowid" "$db")
            ("sqlite_num_rows" "$result")
            ("sqlite_num_fields" "$result")
            ("sqlite_field_name" "$result" "$field_index")
            ("sqlite_seek" "$result" "$row")
            ("sqlite_rewind" "$result")
            ("sqlite_next" "$result")
            ("sqlite_prev" "$result")
            ("sqlite_valid" "$result")
            ("sqlite_has_more" "$result")
            ("sqlite_has_prev" "$result")
            ("sqlite_escape_string" "$item")
            ("sqlite_busy_timeout" "$db" "$ms")
            ("sqlite_last_error" "$db")
            ("sqlite_error_string" "$error_code")
            ("sqlite_unbuffered_query" "$query" "$db" "[$result_type]" "[&$error_message]")
            ("sqlite_create_aggregate" "$db" "$funcname" "$step_func" "$finalize_func" "[$num_args]")
            ("sqlite_create_function" "$db" "$funcname" "$callback" "[$num_args]")
            ("sqlite_factory" "$filename" "[$mode]" "[&$error_message]")
            ("sqlite_udf_encode_binary" "$data")
            ("sqlite_udf_decode_binary" "$data")
            ("sqlite_fetch_column_types" "$table_name" "$db" "[$result_type]")
            ("radius_auth_open")
            ("radius_acct_open")
            ("radius_close")
            ("radius_strerror")
            ("radius_config")
            ("radius_add_server")
            ("radius_create_request")
            ("radius_put_string")
            ("radius_put_int")
            ("radius_put_attr")
            ("radius_put_addr")
            ("radius_put_vendor_string")
            ("radius_put_vendor_int")
            ("radius_put_vendor_attr")
            ("radius_put_vendor_addr")
            ("radius_send_request")
            ("radius_get_attr")
            ("radius_get_vendor_attr")
            ("radius_cvt_addr")
            ("radius_cvt_int")
            ("radius_cvt_string")
            ("radius_request_authenticator")
            ("radius_server_secret")
            ("radius_demangle")
            ("radius_demangle_mppe_key")
            ("pg_connect" "$connection_string" "[$connect_type]" "[$host]" "[$port]" "[$options]" "[$tty]" "[$database]")
            ("pg_pconnect" "$connection_string" "[$host]" "[$port]" "[$options]" "[$tty]" "[$database]")
            ("pg_close" "[$connection]")
            ("pg_connection_status" "$connection")
            ("pg_connection_busy" "$connection")
            ("pg_connection_reset" "$connection")
            ("pg_host" "[$connection]")
            ("pg_dbname" "[$connection]")
            ("pg_port" "[$connection]")
            ("pg_tty" "[$connection]")
            ("pg_options" "[$connection]")
            ("pg_version" "[$connection]")
            ("pg_ping" "[$connection]")
            ("pg_parameter_status" "$connection" "[$param_name]")
            ("pg_transaction_status" "$connection")
            ("pg_query" "[$connection]" "[$query]")
            ("pg_query_params" "[$connection]" "[$query]" "[$params]")
            ("pg_prepare" "[$connection]" "[$stmtname]" "[$query]")
            ("pg_execute" "[$connection]" "[$stmtname]" "[$params]")
            ("pg_send_query" "$connection" "$query")
            ("pg_send_query_params" "$connection" "$query" "$params")
            ("pg_send_prepare" "$connection" "$stmtname" "$query")
            ("pg_send_execute" "$connection" "$stmtname" "$params")
            ("pg_cancel_query" "$connection")
            ("pg_fetch_result" "$result" "[$row_number]" "[$field_name]")
            ("pg_fetch_row" "$result" "[$row]" "[$result_type]")
            ("pg_fetch_assoc" "$result" "[$row]")
            ("pg_fetch_array" "$result" "[$row]" "[$result_type]")
            ("pg_fetch_object" "$result" "[$row]" "[$class_name]" "[$l]" "[$ctor_params]")
            ("pg_fetch_all" "$result")
            ("pg_fetch_all_columns" "$result" "[$column_number]")
            ("pg_affected_rows" "$result")
            ("pg_get_result" "$connection")
            ("pg_result_seek" "$result" "$offset")
            ("pg_result_status" "$result" "[$result_type]")
            ("pg_free_result" "$result")
            ("pg_last_oid" "$result")
            ("pg_num_rows" "$result")
            ("pg_num_fields" "$result")
            ("pg_field_name" "$result" "$field_number")
            ("pg_field_num" "$result" "$field_name")
            ("pg_field_size" "$result" "$field_number")
            ("pg_field_type" "$result" "$field_number")
            ("pg_field_type_oid" "$result" "$field_number")
            ("pg_field_prtlen" "$result" "[$row]" "[$field_name_or_number]")
            ("pg_field_is_null" "$result" "[$row]" "[$field_name_or_number]")
            ("pg_field_table" "$result" "$field_number" "[$oid_only]")
            ("pg_get_notify" "[$connection]" "[$e]")
            ("pg_get_pid" "[$connection]")
            ("pg_result_error" "$result")
            ("pg_result_error_field" "$result" "$fieldcode")
            ("pg_last_error" "[$connection]")
            ("pg_last_notice" "$connection")
            ("pg_put_line" "[$connection]" "[$query]")
            ("pg_end_copy" "[$connection]")
            ("pg_copy_to" "$connection" "$table_name" "[$delimiter]" "[$null_as]")
            ("pg_copy_from" "$connection" "$table_name" "$rows" "[$delimiter]" "[$null_as]")
            ("pg_trace" "$filename" "[$mode]" "[$connection]")
            ("pg_untrace" "[$connection]")
            ("pg_lo_create" "[$connection]" "[$large_object_id]")
            ("pg_lo_unlink" "[$connection]" "[$large_object_oid]")
            ("pg_lo_open" "[$connection]" "[$large_object_oid]" "[$mode]")
            ("pg_lo_close" "$large_object")
            ("pg_lo_read" "$large_object" "[$len]")
            ("pg_lo_write" "$large_object" "$buf" "[$len]")
            ("pg_lo_read_all" "$large_object")
            ("pg_lo_import" "[$connection]" "[$filename]" "[$large_object_oid]")
            ("pg_lo_export" "[$connection]" "[$objoid]" "[$filename]")
            ("pg_lo_seek" "$large_object" "$offset" "[$whence]")
            ("pg_lo_tell" "$large_object")
            ("pg_escape_string" "[$connection]" "[$data]")
            ("pg_escape_bytea" "[$connection]" "[$data]")
            ("pg_unescape_bytea" "$data")
            ("pg_set_error_verbosity" "[$connection]" "[$verbosity]")
            ("pg_client_encoding" "[$connection]")
            ("pg_set_client_encoding" "[$connection]" "[$encoding]")
            ("pg_meta_data" "$db" "$table")
            ("pg_convert" "$db" "$table" "$values" "[$options]")
            ("pg_insert" "$db" "$table" "$values" "[$options]")
            ("pg_update" "$db" "$table" "$fields" "$ids" "[$options]")
            ("pg_delete" "$db" "$table" "$ids" "[$options]")
            ("pg_select" "$db" "$table" "$ids" "[$options]")
            ("pg_exec" "[$connection]" "[$query]")
            ("pg_getlastoid" "$result")
            ("pg_cmdtuples" "$result")
            ("pg_errormessage" "[$connection]")
            ("pg_numrows" "$result")
            ("pg_numfields" "$result")
            ("pg_fieldname" "$result" "$field_number")
            ("pg_fieldsize" "$result" "$field_number")
            ("pg_fieldtype" "$result" "$field_number")
            ("pg_fieldnum" "$result" "$field_name")
            ("pg_fieldprtlen" "$result" "[$row]" "[$field_name_or_number]")
            ("pg_fieldisnull" "$result" "[$row]" "[$field_name_or_number]")
            ("pg_freeresult" "$result")
            ("pg_result" "$connection")
            ("pg_loreadall" "$large_object")
            ("pg_locreate" "[$connection]" "[$large_object_id]")
            ("pg_lounlink" "[$connection]" "[$large_object_oid]")
            ("pg_loopen" "[$connection]" "[$large_object_oid]" "[$mode]")
            ("pg_loclose" "$large_object")
            ("pg_loread" "$large_object" "[$len]")
            ("pg_lowrite" "$large_object" "$buf" "[$len]")
            ("pg_loimport" "[$connection]" "[$filename]" "[$large_object_oid]")
            ("pg_loexport" "[$connection]" "[$objoid]" "[$filename]")
            ("pg_clientencoding" "[$connection]")
            ("pg_setclientencoding" "[$connection]" "[$encoding]")
            ("ming_setcubicthreshold")
            ("ming_setscale")
            ("ming_useswfversion")
            ("ming_keypress")
            ("ming_useconstants")
            ("ming_setswfcompression")
            ("ncurses_addch")
            ("ncurses_delwin")
            ("ncurses_end")
            ("ncurses_getch")
            ("ncurses_has_colors")
            ("ncurses_init")
            ("ncurses_init_pair")
            ("ncurses_color_content" "$" "&$" "&$" "&$")
            ("ncurses_pair_content" "$" "&$" "&$")
            ("ncurses_move")
            ("ncurses_newwin")
            ("ncurses_refresh")
            ("ncurses_start_color")
            ("ncurses_standout")
            ("ncurses_standend")
            ("ncurses_baudrate")
            ("ncurses_beep")
            ("ncurses_can_change_color")
            ("ncurses_cbreak")
            ("ncurses_clear")
            ("ncurses_clrtobot")
            ("ncurses_clrtoeol")
            ("ncurses_def_prog_mode")
            ("ncurses_reset_prog_mode")
            ("ncurses_def_shell_mode")
            ("ncurses_reset_shell_mode")
            ("ncurses_delch")
            ("ncurses_deleteln")
            ("ncurses_doupdate")
            ("ncurses_echo")
            ("ncurses_erase")
            ("ncurses_werase")
            ("ncurses_erasechar")
            ("ncurses_flash")
            ("ncurses_flushinp")
            ("ncurses_has_ic")
            ("ncurses_has_il")
            ("ncurses_inch")
            ("ncurses_insertln")
            ("ncurses_isendwin")
            ("ncurses_killchar")
            ("ncurses_nl")
            ("ncurses_nocbreak")
            ("ncurses_noecho")
            ("ncurses_nonl")
            ("ncurses_noraw")
            ("ncurses_raw")
            ("ncurses_meta")
            ("ncurses_resetty")
            ("ncurses_savetty")
            ("ncurses_termattrs")
            ("ncurses_use_default_colors")
            ("ncurses_slk_attr")
            ("ncurses_slk_clear")
            ("ncurses_slk_noutrefresh")
            ("ncurses_slk_refresh")
            ("ncurses_slk_restore")
            ("ncurses_slk_touch")
            ("ncurses_attroff")
            ("ncurses_attron")
            ("ncurses_attrset")
            ("ncurses_bkgd")
            ("ncurses_curs_set")
            ("ncurses_delay_output")
            ("ncurses_echochar")
            ("ncurses_halfdelay")
            ("ncurses_has_key")
            ("ncurses_insch")
            ("ncurses_insdelln")
            ("ncurses_mouseinterval")
            ("ncurses_napms")
            ("ncurses_scrl")
            ("ncurses_slk_attroff")
            ("ncurses_slk_attron")
            ("ncurses_slk_attrset")
            ("ncurses_slk_init")
            ("ncurses_slk_set")
            ("ncurses_typeahead")
            ("ncurses_ungetch")
            ("ncurses_vidattr")
            ("ncurses_wrefresh")
            ("ncurses_bkgdset")
            ("ncurses_filter")
            ("ncurses_noqiflush")
            ("ncurses_qiflush")
            ("ncurses_timeout")
            ("ncurses_use_env")
            ("ncurses_addstr")
            ("ncurses_putp")
            ("ncurses_scr_dump")
            ("ncurses_scr_init")
            ("ncurses_scr_restore")
            ("ncurses_scr_set")
            ("ncurses_mvaddch")
            ("ncurses_mvaddchnstr")
            ("ncurses_addchnstr")
            ("ncurses_mvaddchstr")
            ("ncurses_addchstr")
            ("ncurses_mvaddnstr")
            ("ncurses_addnstr")
            ("ncurses_mvaddstr")
            ("ncurses_mvdelch")
            ("ncurses_mvgetch")
            ("ncurses_mvinch")
            ("ncurses_mvwaddstr")
            ("ncurses_insstr")
            ("ncurses_instr" "&$")
            ("ncurses_mvhline")
            ("ncurses_mvcur")
            ("ncurses_init_color")
            ("ncurses_border")
            ("ncurses_define_key")
            ("ncurses_hline")
            ("ncurses_vline")
            ("ncurses_keyok")
            ("ncurses_termname")
            ("ncurses_longname")
            ("ncurses_mousemask" "$" "&$")
            ("ncurses_getmouse" "&$")
            ("ncurses_ungetmouse")
            ("ncurses_mouse_trafo" "&$" "&$")
            ("ncurses_wmouse_trafo" "$" "&$" "&$")
            ("ncurses_waddstr")
            ("ncurses_wnoutrefresh")
            ("ncurses_wclear")
            ("ncurses_wgetch")
            ("ncurses_keypad")
            ("ncurses_wmove")
            ("ncurses_newpad")
            ("ncurses_prefresh")
            ("ncurses_pnoutrefresh")
            ("ncurses_wstandout")
            ("ncurses_wstandend")
            ("ncurses_wattrset")
            ("ncurses_wattron")
            ("ncurses_wattroff")
            ("ncurses_waddch")
            ("ncurses_wborder")
            ("ncurses_whline")
            ("ncurses_wvline")
            ("ncurses_getyx" "$" "&$" "&$")
            ("ncurses_getmaxyx" "$" "&$" "&$")
            ("ncurses_update_panels")
            ("ncurses_panel_window")
            ("ncurses_panel_below")
            ("ncurses_panel_above")
            ("ncurses_replace_panel")
            ("ncurses_move_panel")
            ("ncurses_bottom_panel")
            ("ncurses_top_panel")
            ("ncurses_show_panel")
            ("ncurses_hide_panel")
            ("ncurses_del_panel")
            ("ncurses_new_panel")
            ("xdebug_get_stack_depth")
            ("xdebug_get_function_stack")
            ("xdebug_get_formatted_function_stack")
            ("xdebug_print_function_stack")
            ("xdebug_get_declared_vars")
            ("xdebug_call_class")
            ("xdebug_call_function")
            ("xdebug_call_file")
            ("xdebug_call_line")
            ("xdebug_var_dump")
            ("xdebug_debug_zval")
            ("xdebug_debug_zval_stdout")
            ("xdebug_enable")
            ("xdebug_disable")
            ("xdebug_is_enabled")
            ("xdebug_break")
            ("xdebug_start_trace")
            ("xdebug_stop_trace")
            ("xdebug_get_tracefile_name")
            ("xdebug_get_profiler_filename")
            ("xdebug_dump_aggr_profiling_data")
            ("xdebug_clear_aggr_profiling_data")
            ("xdebug_memory_usage")
            ("xdebug_peak_memory_usage")
            ("xdebug_time_index")
            ("xdebug_start_error_collection")
            ("xdebug_stop_error_collection")
            ("xdebug_get_collected_errors")
            ("xdebug_start_code_coverage")
            ("xdebug_stop_code_coverage")
            ("xdebug_get_code_coverage")
            ("xdebug_get_function_count")
            ("xdebug_dump_superglobals")
            ("xdebug_get_headers")
            ))
    hash))

(defun php-function-and-argument ()
  (condition-case error
      (let ((start-pos (point))
            argument
            (function-name-chars-regex "[-A-Za-z[:digit:]_]"))
        (or (save-excursion
              (when (save-excursion
                      (while (or (plusp (skip-syntax-forward "_w\\s-"))
                                 (plusp (skip-chars-forward "\n"))))
                      (equal (char-after) ?\())
                (list (thing-at-point 'symbol)
                      nil)))
            (save-excursion
              (while (in-string-p)
                (backward-char))
              (let* (( closing-paren
                       (save-excursion
                         (when (search-backward ")" nil t)
                           (point))))
                     ( boundary
                       (save-excursion (search-backward "(")
                                       (when (and closing-paren
                                                  (> closing-paren (point)))
                                         (error "not inside argument list"))
                                       (point)))
                     ( argument-number
                       (let ((counter 0))
                         (while (search-backward "," boundary t)
                           (incf counter))
                         counter))
                     ( function-name
                       (progn (goto-char boundary)
                              (re-search-backward function-name-chars-regex)
                              (forward-char)
                              (setq boundary (point))
                              (ignore-errors
                                (while
                                    (progn (backward-char)
                                           (when (looking-at
                                                  function-name-chars-regex)
                                             (if (equal (point) (point-min))
                                                 (error "beginning of buffer")
                                                 t))))
                                (forward-char))
                              (buffer-substring (point) boundary))))
                (list function-name argument-number)))))
    (error nil
           ;; (message "php-eldoc Error: %s "
           ;;          error)
           )))

(defun php-eldoc-function ()
  (let* ((func (php-function-and-argument))
         (hash-result (when func
                        (gethash (car func) php-eldoc-functions-hash)))
         (arguments "")
         (counter 0))
    (when hash-result
      (cl-dolist (arg hash-result)
        (setq arguments
              (concat arguments
                      (if (equal counter (second func))
                          (propertize arg 'face '(:weight bold))
                          arg)
                      ", "))
        (incf counter)))
    (when (>= (length arguments) 2)
      (setq arguments (substring arguments 0 (- (length arguments) 2))))
    (when hash-result
      (concat (propertize (first func) 'face 'font-lock-function-name-face)
              "( " arguments " )")
      )))

(defun php-eldoc-probe-callback (orignial-buffer)
  (goto-char (point-min))
  (search-forward "\n\n")
  (delete-region (point-min) (point))
  (eval-buffer)
  (kill-buffer)
  (set-buffer orignial-buffer)
  (setq-local
   php-eldoc-functions-hash
   (let ((hash (make-hash-table :size 2500 :test 'equal)))
     (cl-dolist (func php-remote-functions)
       (puthash (car func) (rest func) hash))
     hash)))

(defun php-eldoc-probe-load (url)
  (url-retrieve
   url `(lambda (&rest ignore)
          (php-eldoc-probe-callback
           ,(current-buffer)))))

(defun php-eldoc-ac-candidates ()
  (let (result)
    (maphash (lambda (key value)
               (push key result))
             php-eldoc-functions-hash)
    result))

(eval-after-load 'auto-complete
  '(ac-define-source php-eldoc
    '((candidates . php-eldoc-ac-candidates)
      (cache)
      (symbol . "f"))))

;;;###autoload
(defun php-eldoc-enable ()
  (interactive)
  (when (and (fboundp 'auto-complete-mode)
             auto-complete-mode)
    (pushnew 'ac-source-php-eldoc ac-sources))
  (setq-local eldoc-documentation-function 'php-eldoc-function)
  (eldoc-mode 1))

(provide 'php-eldoc)
;;; php-eldoc.el ends here
